<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Api\Helper;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ApiHelper
{
    /**
     * Replaces template parameters in the given url.
     *
     * @param string $url The query string builder to replace the template parameters
     * @param array $parameters The parameters to replace in the url
     * @param bool $encode Should parameters be URL-encoded?
     *
     * @return string The processed url
     */
    public static function appendUrlWithTemplateParameters(string $url, array $parameters, bool $encode = true): string
    {
        foreach ($parameters as $key => $value) {
            if (is_null($value)) {
                $replaceValue = '';
            } elseif (is_array($value)) {
                $val = array_map('strval', $value);
                $val = $encode ? array_map('urlencode', $val) : $val;
                $replaceValue = implode('/', $val);
            } else {
                $val = (string) $value;
                $replaceValue = $encode ? urlencode($val) : $val;
            }

            $url = str_replace('{' . (string) $key . '}', $replaceValue, $url);
        }

        return $url;
    }
}
