<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Api\Manager;

use JustIdea\ExpertSender\Api\Client\HttpClientInterface;
use JustIdea\ExpertSender\Api\Request\AbstractApiRequest;
use JustIdea\ExpertSender\Api\Response\ErrorResponse;
use JustIdea\ExpertSender\Api\Response\SuccessResponse;

if (!defined('_PS_VERSION_')) {
    exit;
}

class RequestApiManager
{
    private $client;

    public function __construct(HttpClientInterface $client)
    {
        $this->client = $client;
    }

    public function sendRequest(AbstractApiRequest $request)
    {
        $httpMethod = $request->getMethod();
        $url = $request->getUrl();
        $headers = $request->getHeaders();
        $body = $request->getBody();

        $response = $this->client->send($httpMethod, $url, $headers, $body);

        return $this->handleResponse($response);
    }

    public function handleResponse($response)
    {
        if ($response->isSuccess()) {
            return new SuccessResponse($response->getStatusCode(), $response->getData());
        }

        return new ErrorResponse($response->getStatusCode(), isset($response->getData()['title']) ? $response->getData()['title'] : '', $response->getData());
    }
}
