<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Api\Provider;

use JustIdea\ExpertSender\Api\ApiRequestInterface;
use JustIdea\ExpertSender\Api\Exception\ExpertSenderApiException;
use JustIdea\ExpertSender\Api\RestApiRequest;
use JustIdea\ExpertSender\Core\Config\Config;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ApiRequestProvider implements ApiRequestProviderInterface
{
    private $restApiRequest;

    public function __construct(RestApiRequest $restApiRequest)
    {
        $this->restApiRequest = $restApiRequest;
    }

    /**
     * @throws ExpertSenderApiException
     */
    public function getApiRequest(): ApiRequestInterface
    {
        $request = \Configuration::get(Config::API_TYPE);

        if (Config::REST_API === $request) {
            return $this->restApiRequest;
        }

        if (Config::SOAP_API === $request) {
            return ExpertSenderApiException::notImplemented(null, ['api_type' => $request, 'method' => __METHOD__]);
        }

        throw ExpertSenderApiException::missingApiType($request);
    }
}
