<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Api;

use JustIdea\ExpertSender\Api\Configuration\ApiConfigurationInterface;
use JustIdea\ExpertSender\Api\Exception\ExpertSenderApiException;
use JustIdea\ExpertSender\Api\Manager\RequestApiManager;
use JustIdea\ExpertSender\Api\Request\GetApiRequest;
use JustIdea\ExpertSender\Api\Request\PostApiRequest;
use JustIdea\ExpertSender\Core\Config\Config;

if (!defined('_PS_VERSION_')) {
    exit;
}

class RestApiRequest implements ApiRequestInterface
{
    /**
     * @var ApiConfigurationInterface
     */
    private $configuration;

    /**
     * @var RequestApiManager
     */
    private $apiManager;

    public function __construct(
        ApiConfigurationInterface $configuration,
        RequestApiManager $apiManager
    ) {
        $this->configuration = $configuration;
        $this->apiManager = $apiManager;
    }

    public function get(string $endpointMethod, \JsonSerializable $requestModel)
    {
        if (!$this->configuration->getToken()) {
            throw ExpertSenderApiException::missingApiToken();
        }

        $httpBody = array_merge(
            $requestModel->jsonSerialize()
        );

        return $this->apiManager->sendRequest(new GetApiRequest(
            $this->configuration->getBaseUrl() . $endpointMethod,
            $httpBody,
            [$this->configuration->getTokenPrefix() => $this->configuration->getToken(),
                Config::CONTENT_TYPE_NAME => Config::CONTENT_TYPE_JSON, ]
        ));
    }

    public function post(string $endpointMethod, \JsonSerializable $requestModel)
    {
        if (!$this->configuration->getToken()) {
            throw ExpertSenderApiException::missingApiToken();
        }

        $httpBody = array_merge(
            $requestModel->jsonSerialize()
        );

        return $this->apiManager->sendRequest(new PostApiRequest(
            $this->configuration->getBaseUrl() . $endpointMethod,
            $httpBody,
            [$this->configuration->getTokenPrefix() => $this->configuration->getToken(),
                Config::CONTENT_TYPE_NAME => Config::CONTENT_TYPE_JSON, ]
        ));
    }
}
