<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Config;

if (!defined('_PS_VERSION_')) {
    exit;
}

final class Config
{
    public const OPTION_ON = '1';
    public const OPTION_OFF = '';

    public const CONST_STRING_DESCRPTION = '_description';
    public const CONST_STRING_CRON_DESCRPTION = '_cron_description';
    public const CONST_STRING_DETAILS_DESCRPTION = '_details_description';

    /**
     * Configs names.
     */
    public const API_TOKEN = 'EXPERTSENDER_API_TOKEN';
    public const API_TOKEN_PREFIX = 'EXPERTSENDER_API_TOKEN_PREFIX';
    public const API_TYPE = 'EXPERTSENDER_API_TYPE';
    public const CRON_TOKEN = 'EXPERTSENDER_CRON_TOKEN';
    public const AJAX_TOKEN = 'EXPERTSENDER_AJAX_TOKEN';
    public const ENABLE_JS = 'EXPERTSENDER_ENABLE_JS';
    public const LOGS_DEBUG_MODE = 'EXPERTSENDER_LOGS_DEBUG_MODE';
    public const LOGS_REPORT_STORE_ENABLED = 'EXPERTSENDER_LOGS_REPORT_STORE_ENABLED';
    public const IS_API_TOKEN_VALID = 'EXPERTSENDER_IS_API_TOKEN_VALID';
    public const PROD_URL = 'EXPERTSENDER_PROD_URL';
    public const WEBSITE_ID = 'EXPERTSENDEROFFICIAL_WEBSITE_ID';
    public const IMPORT_ORDER_DATE_FROM = 'EXPERTSENDEROFFICIAL_IMPORT_ORDER_DATE_FROM';
    public const IMPORT_ORDER_DATE_TO = 'EXPERTSENDEROFFICIAL_IMPORT_ORDER_DATE_TO';
    public const IMPORT_CUSTOMER_DATE_FROM = 'EXPERTSENDEROFFICIAL_IMPORT_CUSTOMER_DATE_FROM';
    public const IMPORT_CUSTOMER_DATE_TO = 'EXPERTSENDEROFFICIAL_IMPORT_CUSTOMER_DATE_TO';
    public const IMPORT_CUSTOMER_NEWSLETTER_CONSENT = 'EXPERTSENDEROFFICIAL_IMPORT_CUSTOMER_NEWSLETTER_CONSENT';
    public const IMPORT_CUSTOMER_OPTIN_CONSENT = 'EXPERTSENDEROFFICIAL_IMPORT_CUSTOMER_OPTIN_CONSENT';
    public const SYNC_ORDERS = 'orders';
    public const LAST_SYNCED_ORDER_ID = 'EXPERTSENDEROFFICIAL_LAST_SYNCED_ORDER_ID';
    public const SYNC_PROCESS_ORDER_IN_PROGRESS = 'EXPERTSENDEROFFICIAL_SYNC_PROCESS_ORDER_IN_PROGRESS';
    public const SYNC_PROCESS_ORDER_FINISHED = 'EXPERTSENDEROFFICIAL_SYNC_PROCESS_ORDER_FINISHED';
    public const LASTTIME_SYNC_ORDER_DATE = 'EXPERTSENDER_LASTTIME_SYNC_ORDER_DATE';
    public const SYNC_CUSTOMERS = 'customers';
    public const SYNC_RESET = 'ecdp_sync_reset';
    public const SYNC_PROCESS_CUSTOMER_IN_PROGRESS = 'EXPERTSENDEROFFICIAL_SYNC_PROCESS_CUSTOMER_IN_PROGRESS';
    public const SYNC_PROCESS_CUSTOMER_FINISHED = 'EXPERTSENDEROFFICIAL_SYNC_PROCESS_CUSTOMER_FINISHED';
    public const SYNC_BATCH_SIZE = 'EXPERTSENDEROFFICIAL_SYNC_BATCH_SIZE';
    public const SYNC_INCLUDE_PHONE = 'EXPERTSENDEROFFICIAL_SYNC_INCLUDE_PHONE';
    public const LAST_SYNCED_CUSTOMER_ID = 'EXPERTSENDEROFFICIAL_LAST_SYNCED_CUSTOMER_ID';
    public const LASTTIME_SYNC_CUSTOMER_DATE = 'EXPERTSENDER_SYNC_CUSTOMERS_DATE';
    public const LOGS_TEXTAREA = 'EXPERTSENDER_LOGS_TEXTAREA';
    public const LOGS_PROGRESS_BAR = 'EXPERTSENDER_LOGS_PROGRESS_BAR';

    /**
     * Configs values.
     */
    public const CONTENT_TYPE_NAME = 'Content-Type';
    public const CONTENT_TYPE_JSON = 'application/json';
    public const REST_API = 'REST_API';
    public const SOAP_API = 'SOAP_API';

    /**
     * Form id names.
     */
    public const LOG_CONFIG_FORM_NAME = 'expertsender_logs_settings_form';
    public const SETTINGS_API_CONFIG_FORM_NAME = 'expertsender_api_settings_form';
    public const SETTINGS_INTEGRATION_CONFIG_FORM_NAME = 'expertsender_integration_settings_form';
    public const IMPORT_ORDER_FORM_NAME = 'expertsender_import_order_form';
    public const IMPORT_CUSTOMER_FORM_NAME = 'expertsender_import_customer_form';
    public const CUSTOMERS_ASSOCIATION_CONFIG_FORM_NAME = 'expertsender_customers_association_settings_form';
    public const CONSENTS_ASSOCIATION_CONFIG_FORM_NAME = 'expertsender_consents_association_settings_form';
    public const ORDERS_ASSOCIATION_CONFIG_FORM_NAME = 'expertsender_orders_association_settings_form';
    public const ORDER_STATES_ASSOCIATION_CONFIG_FORM_NAME = 'expertsender_order_states_association_settings_form';
    public const PRODUCTS_ASSOCIATION_CONFIG_FORM_NAME = 'expertsender_products_association_settings_form';
    public const SYNC_PROCESS_CONFIG_FORM_NAME = 'expertsender_process_sync_settings_form';
    public const SYNC_SETTINGS_CONFIG_FORM_NAME = 'expertsender_sync_settings_form';

    /**
     * Form submit button names.
     */
    public const LOG_PANEL_FORM_SUBMIT_NAME = 'submitExpertSenderLogsFormOptions';
    public const LOG_PANEL_EXPORT_LOGS_TO_CSV_SUBMIT_NAME = 'submitExpertSenderLogsToCsvExport';
    public const LOG_PANEL_EXPORT_LOGS_TO_ZIP_FILE_SUBMIT_NAME = 'submitExpertSenderLogsToZipFileExport';
    public const LOG_PANEL_DELETE_LOGS_SUBMIT_NAME = 'submitExpertSenderLogsDelete';
    public const LOG_PANEL_DELETE_LOGS_FILES_SUBMIT_NAME = 'submitExpertSenderLogsFilesDelete';
    public const LOG_TYPE_REQUEST = 'request';
    public const LOG_TYPE_RESPONSE = 'response';
    public const LOG_TYPE_CONTEXT = 'context';

    /**
     * Form input names.
     */
    public const SETTINGS_PANEL_API_FORM_SUBMIT = 'submitExpertSenderTokenOptions';
    public const SETTINGS_PANEL_INTEGRATION_FORM_SUBMIT = 'submitExpertSenderIntegrationOptions';
    public const IMPORT_ORDER_FORM_SUBMIT = 'submitExpertSenderImportOrdersOptions';
    public const IMPORT_CUSTOMER_FORM_SUBMIT = 'submitExpertSenderImportCustomersOptions';
    public const OPTIONS_PANEL_ORDER_DISCOUNT_RECALCULATE_SUBMIT = 'submitExpertSenderOrderDiscountRecalculateOptions';
    public const OPTIONS_SYNC_SUBMIT = 'ExpertSenderSyncOptions';
    public const OPTIONS_START_SYNC_SUBMIT = 'submitExpertSenderStartSyncOptions';
    public const OPTIONS_STOP_SYNC_SUBMIT = 'submitExpertSenderStopSyncOptions';
    public const SYNC_OPTION_SETTINGS_SUBMIT = 'submitExpertSenderSyncOptionSettings';

    /**
     * Module tab controllers.
     */
    public const LEGACY_PARENT_CONTROLLER = 'IMPROVE';
    public const SIDEBAR_CONTROLLER = 'AdminExpertSenderSidebar';
    public const TAB_CONTROLLER = 'AdminExpertSenderTab';

    /**
     * Module controllers.
     */
    public const SETTINGS_CONTROLLER = 'AdminExpertSenderSettings';
    public const SYNC_CONTROLLER = 'AdminExpertSenderSync';
    public const LOG_CONTROLLER = 'AdminExpertSenderLog';
    public const ASSOCIATION_CONTROLLER = 'AdminExpertSenderAssociation';
    public const ASSOCIATION_CUSTOMERS_CONTROLLER = 'AdminExpertSenderAssociationCustomers';
    public const ASSOCIATION_ORDERS_CONTROLLER = 'AdminExpertSenderAssociationOrders';
    public const ASSOCIATION_ORDER_STATES_CONTROLLER = 'AdminExpertSenderAssociationOrderStates';
    public const ASSOCIATION_PRODUCTS_CONTROLLER = 'AdminExpertSenderAssociationProducts';
    public const ASSOCIATION_CONSENTS_CONTROLLER = 'AdminExpertSenderAssociationConsents';
    public const IMPORT_ORDER_CONTROLLER = 'AdminExpertSenderImportOrder';
    public const IMPORT_CUSTOMER_CONTROLLER = 'AdminExpertSenderImportCustomer';
    public const LOGGER_AJAX_CONTROLLER = 'AdminExpertSenderLoggerAjax';
    public const AJAX_CONTROLLER = 'AdminExpertSenderAjax';
    public const CRON_CONTROLLER = 'AdminExpertSenderCron';

    private function __construct()
    {
    }

    /**
     * Configuration list to be used in module.
     */
    public static function getConfigList(): array
    {
        return [
            self::API_TOKEN => '',
            self::IS_API_TOKEN_VALID => 0,
            self::API_TOKEN_PREFIX => 'x-api-key',
            self::PROD_URL => 'https://api.ecdp.app',
            self::API_TYPE => self::REST_API,
            self::CRON_TOKEN => md5(_COOKIE_KEY_ . \Configuration::get('PS_SHOP_NAME')),
            self::AJAX_TOKEN => md5(_COOKIE_KEY_ . \Configuration::get('PS_SHOP_DOMAIN')),
            self::LOGS_DEBUG_MODE => 0,
            self::LOGS_REPORT_STORE_ENABLED => 0,
            self::SYNC_BATCH_SIZE => 20,
            self::SYNC_INCLUDE_PHONE => 0,
            self::WEBSITE_ID => '',
            self::ENABLE_JS => 0,
        ];
    }

    public static function getHookList(): array
    {
        return [
            'actionObjectExpertSenderOrderStateMappingAddAfter',
            'actionObjectExpertSenderOrderStateMappingUpdateAfter',

            'actionCustomerAccountAdd',
            'actionCustomerAccountUpdate',
            'actionOrderReturn',

            'actionObjectAddressAddAfter',
            'actionObjectAddressDeleteAfter',
            'actionObjectAddressUpdateAfter',
            'actionObjectCustomerAddAfter',
            'actionObjectCustomerDeleteAfter',
            'actionObjectCustomerUpdateAfter',
            'actionObjectCustomerUpdateBefore',
            'actionObjectCustomerAddressAddAfter',
            'actionObjectCustomerAddressDeleteAfter',
            'actionObjectCustomerAddressUpdateAfter',
            'actionObjectOrderAddAfter',
            'actionObjectOrderDeleteAfter',
            'actionObjectOrderUpdateAfter',
            'actionObjectOrderDetailUpdateAfter',

            'actionOrderHistoryAddAfter',
            'actionProductCancel',
            'actionSubmitCustomerAddressForm',

            'actionFrontControllerSetMedia',
        ];
    }

    /**
     * Batch size values used in repositories.
     */
    public static function getBatchSizeValuesArray(): array
    {
        return [
            '5' => [
                'id' => 5,
                'name' => '5',
            ],
            '10' => [
                'id' => 10,
                'name' => '10',
            ],
            '20' => [
                'id' => 20,
                'name' => '20',
            ],
            '50' => [
                'id' => 50,
                'name' => '50',
            ],
            '100' => [
                'id' => 100,
                'name' => '100',
            ],
        ];
    }
}
