<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Customer\DTO;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ImportCustomerRequestData implements \JsonSerializable
{
    /**
     * @var string
     */
    private $dateFrom;

    /**
     * @var string
     */
    private $dateTo;

    /**
     * @var array
     */
    private $consentOptions;

    public function __construct(
        string $dateFrom,
        string $dateTo,
        array $consentOptions
    ) {
        $this->dateFrom = $dateFrom;
        $this->dateTo = $dateTo;
        $this->consentOptions = $consentOptions;
    }

    public function getDateFrom(): string
    {
        return $this->dateFrom;
    }

    public function getDateTo(): string
    {
        return $this->dateTo;
    }

    public function getConsentOptions(): array
    {
        return $this->consentOptions;
    }

    public function jsonSerialize(): array
    {
        return [
            'dateFrom' => $this->getDateFrom(),
            'dateTo' => $this->getDateTo(),
            'consentOptions' => $this->getConsentOptions(),
        ];
    }

    public static function create(
        string $dateFrom,
        string $dateTo,
        array $consentOptions
    ): self {
        return new self(
            $dateFrom,
            $dateTo,
            $consentOptions
        );
    }
}
