<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Customer\Model;

use JustIdea\ExpertSender\Core\Model\Collection;
use JustIdea\ExpertSender\Infrastructure\Exception\ExpertSenderException;

if (!defined('_PS_VERSION_')) {
    exit;
}

/** Object model for post /orders method */
class ConsentsData extends Collection
{
    /**
     * @var bool
     */
    private $force;

    /**
     * @var int
     */
    private $confirmationMessageId;

    public function __construct(
        bool $force,
        int $confirmationMessageId
    ) {
        $this->force = $force;
        $this->confirmationMessageId = $confirmationMessageId;
    }

    public function getConsents(): array
    {
        $returnArray = [];

        /** @var ConsentValue $item */
        foreach ($this->getAll() as $key => $item) {
            $returnArray[] = [
                'id' => $item->getId(),
                'value' => $item->getValue(),
                'prestaFieldId' => $item->getPrestaFieldId(),
            ];
        }

        return $returnArray;
    }

    public function getForce(): bool
    {
        return $this->force;
    }

    public function getConfirmationMessageId(): int
    {
        return $this->confirmationMessageId;
    }

    protected function validateType($item): void
    {
        if (!$item instanceof ConsentValue) {
            throw ExpertSenderException::invalidArgument(get_class($item), ConsentValue::class);
        }
    }

    public static function create(
        bool $force,
        int $confirmationMessageId
    ): self {
        return new self(
            $force,
            $confirmationMessageId
        );
    }

    public function jsonSerialize(): array
    {
        $items = $this->getAll();

        $returnArray = [
            'consents' => [],
            'force' => $this->getForce(),
            'confirmationMessageId' => $this->getConfirmationMessageId() ? $this->getConfirmationMessageId() : null,
        ];

        /** @var ConsentValue $item */
        foreach ($items as $key => $item) {
            $returnArray['consents'][] = $item->jsonSerialize();
        }

        return $returnArray;
    }
}
