<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Customer\Model;

use JustIdea\ExpertSender\Core\Model\AbstractModel;

if (!defined('_PS_VERSION_')) {
    exit;
}

/** Object model for post /orders method */
class CustomerAttributes extends AbstractModel
{
    /**
     * @var CustomerAttributeDataCollection
     */
    private $customerAttributeDataCollection;

    public function __construct(
        CustomerAttributeDataCollection $customerAttributeDataCollection
    ) {
        $this->customerAttributeDataCollection = $customerAttributeDataCollection;
    }

    public function getCustomerAttributeDataCollection(): CustomerAttributeDataCollection
    {
        return $this->customerAttributeDataCollection;
    }

    public function jsonSerialize(): array
    {
        return $this->getCustomerAttributeDataCollection()->jsonSerialize();
    }

    public static function create(
        CustomerAttributeDataCollection $customerAttributeDataCollection
    ): self {
        return new self(
            $customerAttributeDataCollection
        );
    }

    public static function createCustomerAttributeDataCollection(array $rawCustomerAttributeDataCollection): CustomerAttributeDataCollection
    {
        $customerAttributeDataCollection = CustomerAttributeDataCollection::create();

        if (is_array($rawCustomerAttributeDataCollection)) {
            foreach ($rawCustomerAttributeDataCollection as $key => $rawCustomerAttributeData) {
                $customerAttributeData = CustomerAttributeData::create(
                    (int) $rawCustomerAttributeData['id'],
                    (string) $rawCustomerAttributeData['name'],
                    (string) $rawCustomerAttributeData['type']
                );
                $customerAttributeDataCollection->add($customerAttributeData);
            }
        }

        return $customerAttributeDataCollection;
    }
}
