<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Customer\Provider;

use JustIdea\ExpertSender\Core\Customer\Provider\Queryable\CustomerQueryable as DatabaseQueryable;
use JustIdea\ExpertSender\Core\Customer\Provider\Single\CustomerSingle as DatabaseSingle;
use JustIdea\ExpertSender\Core\Queryable\QueryableInterface;
use JustIdea\ExpertSender\Core\Repository\ExpertSenderCustomerRepositoryInterface;
use JustIdea\ExpertSender\Infrastructure\Adapter\ModuleFactory;

if (!defined('_PS_VERSION_')) {
    exit;
}

class CustomerProvider implements ProviderInterface
{
    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    private $module;

    /**
     * @var ExpertSenderCustomerRepositoryInterface
     */
    private $expertSenderCustomerRepository;

    public function __construct(
        ModuleFactory $moduleFactory,
        ExpertSenderCustomerRepositoryInterface $expertSenderCustomerRepository
    ) {
        $this->module = $moduleFactory->getModule();
        $this->expertSenderCustomerRepository = $expertSenderCustomerRepository;
    }

    public function getMany(): QueryableInterface
    {
        return new DatabaseQueryable(
            $this->module,
            $this->expertSenderCustomerRepository
        );
    }

    public function getOne(\JsonSerializable $requestModel)
    {
        $response = new DatabaseSingle(
            $this->module,
            $this->expertSenderCustomerRepository,
            $requestModel
        );

        return $response->execute();
    }
}
