<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Customer\Provider\Single;

use JustIdea\ExpertSender\Core\Customer\DTO\CustomerSingleRequestData;
use JustIdea\ExpertSender\Core\Customer\Model\CustomerData;
use JustIdea\ExpertSender\Core\Repository\DatabaseCriteria;
use JustIdea\ExpertSender\Core\Repository\ExpertSenderCustomerRepositoryInterface;
use JustIdea\ExpertSender\Core\Single\CommonSingle;
use JustIdea\ExpertSender\Infrastructure\Utility\CustomerInfoUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class CustomerSingle extends CommonSingle
{
    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    private $module;

    /**
     * @var ExpertSenderCustomerRepositoryInterface
     */
    private $expertSenderCustomerRepository;

    /**
     * @var CustomerSingleRequestData
     */
    private $requestObject;

    public function __construct(
        \ExpertSenderOfficial $module,
        ExpertSenderCustomerRepositoryInterface $expertSenderCustomerRepository,
        CustomerSingleRequestData $requestObject
    ) {
        $this->module = $module;
        $this->expertSenderCustomerRepository = $expertSenderCustomerRepository;
        $this->requestObject = $requestObject;
    }

    protected function fetchData(): array
    {
        return $this->expertSenderCustomerRepository->getFullCustomerDetailsWithCriteria((new DatabaseCriteria())
                ->where('c.id_customer', $this->requestObject->getCustomerId()));
    }

    protected function processData(array $data)
    {
        $customers = isset($data) ? $data : [];

        if (!count($customers)) {
            return [];
        }

        $customer = $customers[0];

        return CustomerData::create(
            (int) $customer['id'],
            (string) $customer['email'],
            (string) isset($customer['customerPhone']) ? $customer['customerPhone'] : null,
            (string) $customer['crmId'],
            (string) $customer['visitorId'],
            (string) $customer['firstName'],
            (string) $customer['lastName'],
            (string) $customer['dateOfBirth'],
            CustomerInfoUtility::convertGenderIdToValidFormat((int) $customer['genderId']),
            CustomerData::createCustomAttributeValueCollection([['name' => 'name', 'value' => 'value']]),
            CustomerData::createConsentsData([['name' => 'name', 'value' => 'value']])
        );
    }
}
