<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Action;

use JustIdea\ExpertSender\Core\Order\DTO\ImportOrderRequestData as RequestModel;
use JustIdea\ExpertSender\Core\Repository\DatabaseCriteria;
use JustIdea\ExpertSender\Core\Repository\ExpertSenderOrderRepositoryInterface;
use JustIdea\ExpertSender\Infrastructure\Adapter\ModuleFactory;
use JustIdea\ExpertSender\Infrastructure\Exception\ExpertSenderException;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ImportOrderAction implements ActionInterface
{
    public const FILE_NAME = 'ImportOrderAction';

    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    private $module;

    /**
     * @var ExpertSenderOrderRepositoryInterface
     */
    private $expertSenderOrderRepository;

    public function __construct(
        ModuleFactory $moduleFactory,
        ExpertSenderOrderRepositoryInterface $expertSenderOrderRepository
    ) {
        $this->module = $moduleFactory->getModule();
        $this->expertSenderOrderRepository = $expertSenderOrderRepository;
    }

    /**
     * @param RequestModel $requestModel
     */
    public function run(\JsonSerializable $requestModel)
    {
        $this->module->getLogger()->debug(sprintf($this->module->l('%s - Function called', self::FILE_NAME), __METHOD__));

        try {
            $dateFrom = new \DateTime($requestModel->getDateFrom());
            $dateTo = new \DateTime($requestModel->getDateTo());

            $criteria = (new DatabaseCriteria())
                ->where('o.date_add', $dateFrom->format('Y-m-d H:i:s'), '>=')
                ->where('o.date_add', $dateTo->format('Y-m-d H:i:s'), '<=');

            $this->expertSenderOrderRepository->importOrdersByDateRange($criteria);
        } catch (\Exception $exception) {
            throw ExpertSenderException::unknownError($exception, ['context' => '', 'request' => $requestModel->jsonSerialize()]);
        }

        $this->module->getLogger()->debug(sprintf($this->module->l('%s - Function ended', self::FILE_NAME), __METHOD__));
    }
}
