<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Api\Request;

use JustIdea\ExpertSender\Api\Exception\ApiException;
use JustIdea\ExpertSender\Api\Provider\ApiRequestProviderInterface;
use JustIdea\ExpertSender\Api\Response\ApiResponse;
use JustIdea\ExpertSender\Api\Response\SuccessResponse;
use JustIdea\JiBaselinker\Api\ApiRequestInterface;

if (!defined('_PS_VERSION_')) {
    exit;
}

class GetOrderStatesTemporaryApiRequest implements GetOrderStatesApiRequestInterface
{
    public const URL_ENDPOINT = '/orderattributes';

    /**
     * @var ApiRequestInterface
     */
    private $apiRequest;

    public function __construct(ApiRequestProviderInterface $apiRequestProvider)
    {
        $this->apiRequest = $apiRequestProvider->getApiRequest();
    }

    /**
     * @throws ApiException
     */
    public function call(\JsonSerializable $requestModel)
    {
        $body = json_decode('{"status":200,"data":[{"id":1,"name":"Paid","type":"String"},{"id":2,"name":"Completed","type":"String"},{"id":3,"name":"Placed","type":"String"},{"id":4,"name":"Canceled","type":"String"}]}', true);

        $response = new ApiResponse(200, $body);

        return new SuccessResponse($response->getStatusCode(), $response->getData());
    }

    public function buildEndpointUrl(\JsonSerializable $requestModel): string
    {
        return '';
    }
}
