<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Api\Request;

use JustIdea\ExpertSender\Api\Exception\ApiException;
use JustIdea\ExpertSender\Api\Provider\ApiRequestProviderInterface;
use JustIdea\ExpertSender\Core\Config\Config;
use JustIdea\ExpertSender\Core\Order\DTO\PostOrderApiRequestData;
use JustIdea\ExpertSender\Core\Order\Exception\MissingWebsiteIdException;
use JustIdea\ExpertSender\Infrastructure\Exception\ExpertSenderException;

if (!defined('_PS_VERSION_')) {
    exit;
}

class PostOrderApiRequest implements PostOrderApiRequestInterface
{
    public const URL_ENDPOINT = '/orders';

    /**
     * @var ApiRequestInterface
     */
    private $apiRequest;

    public function __construct(ApiRequestProviderInterface $apiRequestProvider)
    {
        $this->apiRequest = $apiRequestProvider->getApiRequest();
    }

    /**
     * @throws ApiException
     */
    public function call(\JsonSerializable $requestModel)
    {
        try {
            if ((int) \Configuration::get(Config::WEBSITE_ID) === 0) {
                throw MissingWebsiteIdException::missingWebsiteId(null, ['request' => $requestModel->jsonSerialize()]);
            }

            return $this->apiRequest->post($this->buildEndpointUrl($requestModel), $requestModel);
        } catch (ApiException $exception) {
            throw ExpertSenderException::failedToGetSuccessfulApiResponse($exception, ['request' => $requestModel->jsonSerialize()]);
        }
    }

    public function buildEndpointUrl(\JsonSerializable $requestModel): string
    {
        if ($requestModel instanceof PostOrderApiRequestData) {
            return self::URL_ENDPOINT;
        } else {
            throw ExpertSenderException::invalidArgument(get_class($requestModel), PostOrderApiRequestData::class);
        }
    }
}
