<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Model;

use JustIdea\ExpertSender\Core\Model\AbstractModel;

if (!defined('_PS_VERSION_')) {
    exit;
}

/** Object model for post /orders method */
class OrderProductData extends AbstractModel
{
    /**
     * @var string
     */
    private $id;

    /**
     * @var string
     */
    private $name;

    /**
     * @var float
     */
    private $price;

    /**
     * @var int
     */
    private $quantity;

    /**
     * @var int
     */
    private $returned;

    /**
     * @var string
     */
    private $url;

    /**
     * @var string
     */
    private $imageUrl;

    /**
     * @var string
     */
    private $category;

    /**
     * @var ProductAttributeValueCollection
     */
    private $productAttributeValueCollection;

    public function __construct(
        string $id,
        string $name,
        float $price,
        int $quantity,
        int $returned,
        string $url,
        string $imageUrl,
        string $category,
        ProductAttributeValueCollection $productAttributeValueCollection
    ) {
        $this->id = $id;
        $this->name = $name;
        $this->price = $price;
        $this->quantity = $quantity;
        $this->returned = $returned;
        $this->url = $url;
        $this->imageUrl = $imageUrl;
        $this->category = $category;
        $this->productAttributeValueCollection = $productAttributeValueCollection;
    }

    public function getId(): string
    {
        return $this->id;
    }

    public function getName(): string
    {
        return $this->name;
    }

    public function getPrice(): float
    {
        return $this->price;
    }

    public function getQuantity(): int
    {
        return $this->quantity;
    }

    public function getReturned(): int
    {
        return $this->returned;
    }

    public function getUrl(): string
    {
        return $this->url;
    }

    public function getImageUrl(): string
    {
        return $this->imageUrl;
    }

    public function getCategory(): string
    {
        return $this->category;
    }

    public function getProductAttributeValueCollection(): ProductAttributeValueCollection
    {
        return $this->productAttributeValueCollection;
    }

    public function jsonSerialize(): array
    {
        return [
            'id' => $this->getId(),
            'name' => $this->getName(),
            'price' => $this->getPrice(),
            'quantity' => $this->getQuantity(),
            'returned' => $this->getReturned(),
            'url' => $this->getUrl(),
            'imageUrl' => $this->getImageUrl(),
            'category' => $this->getCategory(),
            'productAttributes' => $this->getProductAttributeValueCollection()->jsonSerialize(),
        ];
    }
}
