<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Model;

use JustIdea\ExpertSender\Core\Model\AbstractModel;

if (!defined('_PS_VERSION_')) {
    exit;
}

/** Object model for post /orders method */
class OrderStates extends AbstractModel
{
    /**
     * @var OrderStateDataCollection
     */
    private $orderStateDataCollection;

    public function __construct(
        OrderStateDataCollection $orderStateDataCollection
    ) {
        $this->orderStateDataCollection = $orderStateDataCollection;
    }

    public function getOrderStateDataCollection(): OrderStateDataCollection
    {
        return $this->orderStateDataCollection;
    }

    public function jsonSerialize(): array
    {
        return $this->getOrderStateDataCollection()->jsonSerialize();
    }

    public static function create(
        OrderStateDataCollection $orderStateDataCollection
    ): self {
        return new self(
            $orderStateDataCollection
        );
    }

    public static function createOrderStateDataCollection(array $rawOrderStateDataCollection): OrderStateDataCollection
    {
        $orderStateDataCollection = OrderStateDataCollection::create();

        if (is_array($rawOrderStateDataCollection)) {
            foreach ($rawOrderStateDataCollection as $key => $rawOrderStateData) {
                $orderStateData = OrderStateData::create(
                    (int) $rawOrderStateData['id'],
                    (string) $rawOrderStateData['name'],
                    (string) $rawOrderStateData['type']
                );
                $orderStateDataCollection->add($orderStateData);
            }
        }

        return $orderStateDataCollection;
    }
}
