<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Model;

use JustIdea\ExpertSender\Core\Model\AbstractModel;

if (!defined('_PS_VERSION_')) {
    exit;
}

/** Object model for post /orders method */
class ProductAttributes extends AbstractModel
{
    /**
     * @var ProductAttributeDataCollection
     */
    private $productAttributeDataCollection;

    public function __construct(
        ProductAttributeDataCollection $productAttributeDataCollection
    ) {
        $this->productAttributeDataCollection = $productAttributeDataCollection;
    }

    public function getProductAttributeDataCollection(): ProductAttributeDataCollection
    {
        return $this->productAttributeDataCollection;
    }

    public function jsonSerialize(): array
    {
        return $this->getProductAttributeDataCollection()->jsonSerialize();
    }

    public static function create(
        ProductAttributeDataCollection $productAttributeDataCollection
    ): self {
        return new self(
            $productAttributeDataCollection
        );
    }

    public static function createProductAttributeDataCollection(array $rawProductAttributeDataCollection): ProductAttributeDataCollection
    {
        $productAttributeDataCollection = ProductAttributeDataCollection::create();

        if (is_array($rawProductAttributeDataCollection)) {
            foreach ($rawProductAttributeDataCollection as $key => $rawProductAttributeData) {
                $productAttributeData = ProductAttributeData::create(
                    (int) $rawProductAttributeData['id'],
                    (string) $rawProductAttributeData['name'],
                    (string) $rawProductAttributeData['type']
                );
                $productAttributeDataCollection->add($productAttributeData);
            }
        }

        return $productAttributeDataCollection;
    }
}
