<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Order\Provider\Single;

use JustIdea\ExpertSender\Core\Config\Config;
use JustIdea\ExpertSender\Core\Order\DTO\OrderSingleRequestData;
use JustIdea\ExpertSender\Core\Order\Model\OrderData;
use JustIdea\ExpertSender\Core\Repository\DatabaseCriteria;
use JustIdea\ExpertSender\Core\Repository\ExpertSenderOrderRepositoryInterface;
use JustIdea\ExpertSender\Core\Single\CommonSingle;
use JustIdea\ExpertSender\Infrastructure\Utility\ArrayUtility;
use JustIdea\ExpertSender\Infrastructure\Utility\TimeZoneUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class OrderSingle extends CommonSingle
{
    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    private $module;

    /**
     * @var ExpertSenderOrderRepositoryInterface
     */
    private $expertSenderOrderRepository;

    /**
     * @var OrderSingleRequestData
     */
    private $requestObject;

    public function __construct(
        \ExpertSenderOfficial $module,
        ExpertSenderOrderRepositoryInterface $expertSenderOrderRepository,
        OrderSingleRequestData $requestObject
    ) {
        $this->module = $module;
        $this->expertSenderOrderRepository = $expertSenderOrderRepository;
        $this->requestObject = $requestObject;
    }

    protected function fetchData(): array
    {
        return $this->expertSenderOrderRepository->getFullOrderDetailsWithCriteria((new DatabaseCriteria())
                ->where('o.id_order', $this->requestObject->getOrderId()));
    }

    protected function processData(array $data)
    {
        $orders = isset($data) ? $data : [];

        if (!count($orders)) {
            return [];
        }

        $order = $orders[0];

        return OrderData::create(
            (string) $order['id'],
            (string) $order['date'],
            isset($order['status']) ? $order['status'] : null,
            (float) $order['totalValue'],
            OrderData::createOrderCustomerData(ArrayUtility::getArray($order['customer'])),
            OrderData::createOrderProductDataCollection(ArrayUtility::getArray($order['products'])),
            (string) ($order['timeZone'] ?? TimeZoneUtility::DEFAULT_TIME_ZONE),
            (int) \Configuration::get(Config::WEBSITE_ID),
            (string) $order['currency'],
            $order['returnsValue'],
            OrderData::createOrderAttributeValueCollection(isset($order['orderAttributes']) ? ArrayUtility::getArray($order['orderAttributes']) : [])
        );
    }
}
