<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings;

use JustIdea\ExpertSender\Core\Model\CollectionCriteria;
use JustIdea\ExpertSender\Core\Shared\Mappings\Model\AttributeFieldLine;
use JustIdea\ExpertSender\Core\Shared\Mappings\Model\PrestashopAttributes;
use JustIdea\ExpertSender\Infrastructure\Utility\ArrayUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractAttributeExtended extends AbstractAttribute
{
    /**
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    final protected function fetchMappingValue(int $fieldId)
    {
        $create_method_name = $this->getFetchMappingValueMethodName($fieldId);

        return method_exists($this, $create_method_name) ?
        $this->{$create_method_name}() :
        [];
    }

    /**
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    final protected function fetchMappingMatchValue(int $fieldId, int $fieldValueId)
    {
        $create_method_name = $this->getFetchMappingMatchValueMethodName($fieldId);

        return method_exists($this, $create_method_name) ?
        $this->{$create_method_name}($fieldValueId) :
        [];
    }

    /**
     * @return array<AttributeFieldLine>
     */
    final protected function fetchAttributeDefinitionRequest(): array
    {
        $results = [];
        $definitions = $this->getFieldDefinitionArray();

        foreach ($definitions as $value) {
            $results[] = AttributeFieldLine::create(
                (int) $value['id'],
                (string) $this->translator->translate($value['id']) ? $this->translator->translate($value['id']) : $value['name']
            )->jsonSerialize();
        }

        return $results;
    }

    /**
     * @return array
     */
    final public function fetchAttributeValuesRequest(): array
    {
        $attributeId = $this->getFieldDefinitionLineId();

        $create_method_name = $this->getAttributeFieldValueMethodName($attributeId);

        return method_exists($this, $create_method_name) ?
        $this->{$create_method_name}() :
        [];
    }

    /**
     * @return array
     */
    abstract protected function getFieldDefinitionArray(): array;

    /**
     * @return int
     */
    abstract protected function getFieldDefinitionLineId(): int;

    /**
     * @return PrestashopAttributes
     */
    public function getAttributeFieldDefinitionLines(): PrestashopAttributes
    {
        /** @var array $data */
        $attributes = $this->getFieldDefinitionArray();

        $result = new PrestashopAttributes(
            $this->translator,
            is_array($attributes) ? ArrayUtility::getArray($attributes) : []
        );

        return $result;
    }

    /**
     * @param string $customerAttribute
     *
     * @return string
     */
    protected function getAttributeFieldValueMethodName(int $attributeId): string
    {
        $definedAttributeLines = $this->getAttributeFieldDefinitionLines()->getAttributesLines();

        if ($definedAttributeLine = $definedAttributeLines->getOneBy((new CollectionCriteria())->where('id', (int) $attributeId))) {
            return 'get' . ucfirst($definedAttributeLine->getMethodName()) . 'AttributeFieldValue';
        }

        return '';
    }

    /**
     * @param string $customerAttribute
     *
     * @return string
     */
    protected function getFetchMappingValueMethodName(int $attributeId): string
    {
        $definedAttributeLines = $this->getAttributeFieldDefinitionLines()->getAttributesLines();

        if ($definedAttributeLine = $definedAttributeLines->getOneBy((new CollectionCriteria())->where('id', (int) $attributeId))) {
            return 'fetch' . ucfirst($definedAttributeLine->getMethodName()) . 'MappingValue';
        }

        return '';
    }

    /**
     * @param string $customerAttribute
     *
     * @return string
     */
    protected function getFetchMappingMatchValueMethodName(int $attributeId): string
    {
        $definedAttributeLines = $this->getAttributeFieldDefinitionLines()->getAttributesLines();

        if ($definedAttributeLine = $definedAttributeLines->getOneBy((new CollectionCriteria())->where('id', (int) $attributeId))) {
            return 'fetch' . ucfirst($definedAttributeLine->getMethodName()) . 'MappingMatchValue';
        }

        return '';
    }
}
