<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings;

use JustIdea\ExpertSender\Core\Customer\Model\CustomAttributeValue;
use JustIdea\ExpertSender\Infrastructure\Utility\FieldsMappingUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractAttributeOrderState extends AbstractAttribute
{
    public const FILE_NAME = 'AbstractAttributeOrderState';

    /**
     * @param array $params
     *
     * @return CustomAttributeValue|OrderAttributeValue|ConsentValue|ProductAttributeValue|null
     */
    public function fetchAttribute(array $params = [])
    {
        $this->params = $params;

        if ($this->validateFetchAttributeRequest()
            && $this->isValidFetchAttributeRequest()) {
            return $this->fetchAttributeRequest();
        }

        return null;
    }

    /**
     * @return bool
     */
    public function validateFetchAttributeRequest(): bool
    {
        return is_array($this->params)
        && isset($this->params['id_order']);
    }

    /**
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    public function fetchAttributeRequest()
    {
        $fieldsMapping = FieldsMappingUtility::deserializeFieldsMapping((string) $this->params['object']->{'fields_mapping'});

        if ((int) $fieldsMapping['id_mapping_field_value'] > 0) {
            return $this->fetchMappingMatchValue((int) $fieldsMapping['id_mapping_field'], (int) $fieldsMapping['id_mapping_field_value']);
        } else {
            return $this->fetchMappingValue((int) $fieldsMapping['id_mapping_field']);
        }
    }
}
