<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings;

use JustIdea\ExpertSender\Core\Shared\Mappings\Model\AttributeFieldLine;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractOrderStateAttribute extends AbstractAttribute
{
    /**
     * @param array $params
     *
     * @return array<AttributeFieldLine>
     */
    public function fetchAttributeDefinition(array $params = [])
    {
        $this->params = $params;

        if ($this->isValidFetchAttributeDefinitionRequest()) {
            $results = [];

            /**
             * @var array<AttributeFieldLine> $definitions
             */
            $definitions = $this->fetchAttributeDefinitionRequest();

            foreach ($definitions as $value) {
                $results[] = AttributeFieldLine::create(
                    (int) $value['id'],
                    (string) ($this->translator->translate($value['id']) ? $this->translator->translate($value['id']) : $value['name']),
                    (bool) (isset($value['disabled']) ? $value['disabled'] : false)
                )->jsonSerialize();
            }

            return $results;
        }

        return null;
    }
}
