<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\ConsentAttribute\NewsletterConsentAttribute;

use JustIdea\ExpertSender\Core\Customer\Model\ConsentsData;
use JustIdea\ExpertSender\Core\Customer\Model\ConsentValue;
use JustIdea\ExpertSender\Core\Enum\ConsentConfirmationStatus;
use JustIdea\ExpertSender\Core\Shared\Mappings\AbstractConsentAttribute;
use JustIdea\ExpertSender\Infrastructure\Utility\FieldsMappingUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class NewsletterConsentAttribute extends AbstractConsentAttribute
{
    /**
     * @return bool
     */
    protected function isValidFetchAttributeRequest(): bool
    {
        return isset($this->params['id_customer'])
        && $this->params['object'] instanceof \ExpertSenderConsentMapping;
    }

    /**
     * @param int $fieldId
     *
     * @return ConsentsData|null
     *
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function fetchMappingValue(int $fieldId): ?ConsentsData
    {
        $customerId = $this->params['id_customer'];
        $prestaFieldId = (int) $this->params['object']->id_field;

        $mappingsField = FieldsMappingUtility::deserializeConsentFieldsMapping((string) $this->params['object']->{'fields_mapping'});
        $doubleOptin = $mappingsField['double_optin'];
        $doubleOptinConfId = $mappingsField['double_optin_conf_id'];

        $query = new \DbQuery();
        $query->select('c.newsletter AS value')
        ->from(\Customer::$definition['table'], 'c')
        ->innerJoin(\ExpertSenderCustomerConsent::$definition['table'], 'ecc', 'c.id_customer = ecc.id_customer')
        ->where('c.id_customer = ' . (int) $customerId)
        ->where('ecc.id_field = ' . (int) $prestaFieldId)
        ->where('ecc.synced = 0');

        $result = \Db::getInstance()->getRow($query);

        if ($result) {
            return $this->createConsentsData(
                ConsentValue::create(
                    (int) $this->params['object']->id_expertsender_field,
                    ((bool) $result['value']) ? ($doubleOptin ? ConsentConfirmationStatus::AWAITING_CONFIRMATION : ConsentConfirmationStatus::TRUE) : ConsentConfirmationStatus::FALSE,
                    $prestaFieldId
                ),
                false,
                $doubleOptinConfId
            );
        }

        return null;
    }

    /**
     * @param int $fieldId
     * @param int $fieldValueId
     *
     * @return ConsentsData|null
     *
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function fetchMappingMatchValue(int $fieldId, int $fieldValueId): ?ConsentsData
    {
        return $this->fetchMappingValue($fieldId);
    }

    /**
     * @return bool
     */
    protected function isValidFetchAttributeDefinitionRequest(): bool
    {
        return false;
    }

    /**
     * @return array<AttributeFieldLine>
     */
    protected function fetchAttributeDefinitionRequest(): array
    {
        return [];
    }

    /**
     * @return bool
     */
    protected function isValidFetchAttributeValuesRequest(): bool
    {
        return false;
    }

    /**
     * @return array
     */
    public function fetchAttributeValuesRequest(): array
    {
        return [];
    }
}
