<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\CustomerAttribute;

use JustIdea\ExpertSender\Core\Enum\CustomAttributeDefinition;
use JustIdea\ExpertSender\Core\Shared\Mappings\AbstractAttributeFactory;
use JustIdea\ExpertSender\Core\Shared\Mappings\AttributeInterface;
use JustIdea\ExpertSender\Core\Shared\Mappings\CustomerAttribute\NewsletterCustomerAttribute\NewsletterCustomerAttribute;
use JustIdea\ExpertSender\Core\Shared\Mappings\CustomerAttribute\OptinCustomerAttribute\OptinCustomerAttribute;
use JustIdea\ExpertSender\Core\Shared\Mappings\CustomerAttribute\TableCustomerAttribute\TableCustomerAttribute;

if (!defined('_PS_VERSION_')) {
    exit;
}

class CustomerAttributeFactory extends AbstractAttributeFactory implements CustomerAttributeFactoryInterface
{
    protected function getAttributeDefinitionArray(): array
    {
        return [
            CustomAttributeDefinition::PS_CUSTOMER_TABLE => [
                'id' => CustomAttributeDefinition::PS_CUSTOMER_TABLE,
                'name' => 'Customer details',
                'methodName' => 'tableCustomer',
            ],
            CustomAttributeDefinition::PS_NEWSLETTER => [
                'id' => CustomAttributeDefinition::PS_NEWSLETTER,
                'name' => 'Newsletter subscription',
                'methodName' => 'newsletterCustomer',
            ],
            CustomAttributeDefinition::PS_OPTIN => [
                'id' => CustomAttributeDefinition::PS_OPTIN,
                'name' => 'Partner offers',
                'methodName' => 'optinCustomer',
            ],
        ];
    }

    /**
     * @return AttributeInterface
     */
    public function getNewsletterCustomerAttribute(): AttributeInterface
    {
        return new NewsletterCustomerAttribute($this->module, $this->translator);
    }

    /**
     * @return AttributeInterface
     */
    public function getOptinCustomerAttribute(): AttributeInterface
    {
        return new OptinCustomerAttribute($this->module, $this->translator);
    }

    /**
     * @return AttributeInterface
     */
    public function getTableCustomerAttribute(): AttributeInterface
    {
        return new TableCustomerAttribute($this->module, $this->translator);
    }
}
