<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\CustomerAttribute\OptinCustomerAttribute;

use JustIdea\ExpertSender\Core\Customer\Model\CustomAttributeValue;
use JustIdea\ExpertSender\Core\Shared\Mappings\AbstractAttribute;

if (!defined('_PS_VERSION_')) {
    exit;
}

class OptinCustomerAttribute extends AbstractAttribute
{
    /**
     * @return bool
     */
    protected function isValidFetchAttributeRequest(): bool
    {
        return isset($this->params['id_customer'])
        && $this->params['object'] instanceof \ExpertSenderCustomerMapping;
    }

    /**
     * @param int $fieldId
     *
     * @return CustomAttributeValue|null
     *
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function fetchMappingValue(int $fieldId): ?CustomAttributeValue
    {
        $customerId = $this->params['id_customer'];

        $query = new \DbQuery();
        $query->select('c.optin AS value')
            ->from('customer', 'c')
            ->where('c.id_customer = ' . $customerId);

        $result = \Db::getInstance()->getRow($query);

        if ($result) {
            return CustomAttributeValue::create(
                (string) $this->params['object']->id_expertsender_field,
                (string) $result['value']
            );
        }

        return null;
    }

    /**
     * @param int $fieldId
     * @param int $fieldValueId
     *
     * @return CustomAttributeValue|null
     *
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function fetchMappingMatchValue(int $fieldId, int $fieldValueId): ?CustomAttributeValue
    {
        return null;
    }

    /**
     * @return bool
     */
    protected function isValidFetchAttributeDefinitionRequest(): bool
    {
        return false;
    }

    /**
     * @return array<AttributeFieldLine>
     */
    protected function fetchAttributeDefinitionRequest(): array
    {
        return [];
    }

    /**
     * @return bool
     */
    protected function isValidFetchAttributeValuesRequest(): bool
    {
        return false;
    }

    /**
     * @return array
     */
    public function fetchAttributeValuesRequest(): array
    {
        return [];
    }
}
