<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\Model;

use JustIdea\ExpertSender\Core\Model\AbstractModel;
use JustIdea\ExpertSender\Core\Shared\Mappings\Translator\AttributesTranslatorInterface;

if (!defined('_PS_VERSION_')) {
    exit;
}

/** Object model for post /orders method */
class PrestashopAttributes extends AbstractModel
{
    /**
     * @var AttributesLines
     */
    private $attributesLines;

    /**
     * @var AttributesTranslatorInterface
     */
    private $translator;

    public function __construct(
        AttributesTranslatorInterface $translator,
        array $rawAttributesLines
    ) {
        $this->translator = $translator;
        $this->attributesLines = $this->createAttributesLines($rawAttributesLines);
    }

    public function getAttributesLines(): AttributesLines
    {
        return $this->attributesLines;
    }

    public function jsonSerialize(): array
    {
        return $this->getAttributesLines()->jsonSerialize();
    }

    public function createAttributesLines(array $rawAttributesLines): AttributesLines
    {
        $attributesLines = AttributesLines::create();

        if (is_array($rawAttributesLines)) {
            foreach ($rawAttributesLines as $key => $rawAttributesLine) {
                $attributesLine = AttributesLine::create(
                    (int) $rawAttributesLine['id'],
                    (string) $this->translator->translate($rawAttributesLine['id']) ? $this->translator->translate($rawAttributesLine['id']) : $rawAttributesLine['name'],
                    $rawAttributesLine['methodName']
                );
                $attributesLines->add($attributesLine);
            }
        }

        return $attributesLines;
    }
}
