<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\OrderState\OrderStateAttribute;

use JustIdea\ExpertSender\Core\Order\Model\OrderStateValue;
use JustIdea\ExpertSender\Core\Shared\Mappings\AbstractOrderStateAttribute;
use JustIdea\ExpertSender\Core\Shared\Mappings\Model\AttributeFieldLine;

if (!defined('_PS_VERSION_')) {
    exit;
}

class OrderStateAttribute extends AbstractOrderStateAttribute
{
    public const FILE_NAME = 'OrderStateAttribute';

    /**
     * @return bool
     */
    protected function isValidFetchAttributeRequest(): bool
    {
        return isset($this->params['id_order'])
        && isset($this->params['id_order_state'])
        && $this->params['object'] instanceof \ExpertSenderOrderStateMapping;
    }

    /**
     * @param int $fieldId
     *
     * @return OrderStateValue|null
     *
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    public function fetchMappingValue(int $fieldId): ?OrderStateValue
    {
        return OrderStateValue::create(
            (string) $this->params['object']->expertsender_field_name
        );
    }

    /**
     * @param int $fieldId
     * @param int $fieldValueId
     *
     * @return OrderStateValue|null
     *
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function fetchMappingMatchValue(int $fieldId, int $fieldValueId): ?OrderStateValue
    {
        return $this->fetchMappingValue($fieldId);
    }

    /**
     * @return bool
     */
    protected function isValidFetchAttributeDefinitionRequest(): bool
    {
        return is_array($this->params);
    }

    /**
     * @return array<AttributeFieldLine>
     */
    protected function fetchAttributeDefinitionRequest(): array
    {
        $results = [];

        $mappingId = isset($this->params['objectId']) ? (int) $this->params['objectId'] : 0;

        $query = new \DbQuery();
        $query->select('
                os.id_order_state AS id,
                osl.name,
                IFNULL(osmr.id_order_state_mapping, 0) AS used'
        )
            ->from('order_state', 'os')
            ->leftJoin('order_state_lang', 'osl', 'os.id_order_state = osl.id_order_state AND osl.id_lang = ' . (int) \Configuration::get('PS_LANG_DEFAULT'))
            ->leftJoin(\ExpertSenderOrderStateMappingRelation::$definition['table'], 'osmr', 'osmr.id_order_state = os.id_order_state AND osmr.id_order_state_mapping != ' . $mappingId);

        $definitions = \Db::getInstance()->executeS($query);

        foreach ($definitions as $value) {
            $isDisabled = (bool) $value['used'] > 0;
            $results[] = AttributeFieldLine::create(
                (int) $value['id'],
                (string) $value['name'] . ($isDisabled ? ' (' . $this->module->l('already used', self::FILE_NAME) . ')' : ''),
                $isDisabled
            )->jsonSerialize();
        }

        return $results;
    }

    /**
     * @return bool
     */
    protected function isValidFetchAttributeValuesRequest(): bool
    {
        return false;
    }

    /**
     * @return array
     */
    public function fetchAttributeValuesRequest(): array
    {
        return [];
    }
}
