<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\OrderState\Translator;

use JustIdea\ExpertSender\Core\Shared\Mappings\Translator\AttributesTranslatorInterface;
use JustIdea\ExpertSender\Infrastructure\Adapter\ModuleFactory;
use JustIdea\ExpertSender\Infrastructure\Enum\OrderStates;

if (!defined('_PS_VERSION_')) {
    exit;
}

class OrderStatesTranslator implements AttributesTranslatorInterface
{
    public const FILE_NAME = 'OrderStatesTranslator';

    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    private $module;

    public function __construct(ModuleFactory $moduleFactory)
    {
        $this->module = $moduleFactory->getModule();
    }

    public function translate(int $stateId): ?string
    {
        $messages = $this->getMessages();

        if (isset($messages[$stateId])) {
            return $messages[$stateId];
        }

        return null;
    }

    private function getMessages(): array
    {
        return [
            OrderStates::PS_STATES => $this->module->l('Order states', self::FILE_NAME),
        ];
    }
}
