<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Core\Shared\Mappings\ProductAttribute;

use JustIdea\ExpertSender\Core\Shared\Mappings\AbstractAttributeFactory;
use JustIdea\ExpertSender\Core\Shared\Mappings\AttributeInterface;
use JustIdea\ExpertSender\Core\Shared\Mappings\ProductAttribute\CombinationProductAttribute\CombinationProductAttribute;
use JustIdea\ExpertSender\Core\Shared\Mappings\ProductAttribute\FeatureProductAttribute\FeatureProductAttribute;
use JustIdea\ExpertSender\Infrastructure\Enum\ProductAttributes;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ProductAttributeFactory extends AbstractAttributeFactory implements ProductAttributeFactoryInterface
{
    protected function getAttributeDefinitionArray(): array
    {
        return [
            ProductAttributes::PS_COMBINATIONS => [
                'id' => ProductAttributes::PS_COMBINATIONS,
                'name' => 'Combination',
                'methodName' => 'combinationProduct',
            ],
            ProductAttributes::PS_FEATURES => [
                'id' => ProductAttributes::PS_FEATURES,
                'name' => 'Feature',
                'methodName' => 'featureProduct',
            ],
        ];
    }

    /**
     * @return AttributeInterface
     */
    public function getFeatureProductAttribute(): AttributeInterface
    {
        return new FeatureProductAttribute($this->module, $this->translator);
    }

    /**
     * @return AttributeInterface
     */
    public function getCombinationProductAttribute(): AttributeInterface
    {
        return new CombinationProductAttribute($this->module, $this->translator);
    }
}
