<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Action;

use JustIdea\ExpertSender\Core\Enum\ProcessState;
use JustIdea\ExpertSender\Infrastructure\Exception\ExpertSenderException;
use JustIdea\ExpertSender\Infrastructure\Logger\Cleaner\LogFileCleanerServiceInterface;
use JustIdea\ExpertSender\Infrastructure\Logger\LoggerInterface;

if (!defined('_PS_VERSION_')) {
    exit;
}

class RemoveLogFilesAction implements ActionInterface
{
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * @var LogFileCleanerServiceInterface
     */
    private $logFileCleaner;

    public function __construct(
        LoggerInterface $logger,
        LogFileCleanerServiceInterface $logFileCleaner
    ) {
        $this->logger = $logger;
        $this->logFileCleaner = $logFileCleaner;
    }

    public function run(): string
    {
        $this->logger->debug(sprintf('%s - Function called', __METHOD__));

        $result = ProcessState::SUCCESS;

        try {
            /** @var int $filesRemoved */
            $filesRemoved = (int) $this->logFileCleaner->deleteLogs();

            if (0 === $filesRemoved) {
                $result = ProcessState::NO_AFFECT;
            }
        } catch (\Exception $exception) {
            throw ExpertSenderException::unknownError($exception);
        }

        $this->logger->debug(sprintf('%s - Function ended', __METHOD__));

        return $result;
    }
}
