<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Adapter;

use Configuration as PrestaShopConfiguration;
use JustIdea\ExpertSender\Infrastructure\Context\GlobalShopContextInterface;

if (!defined('_PS_VERSION_')) {
    exit;
}

class Configuration
{
    private $globalShopContext;

    public function __construct(GlobalShopContextInterface $globalShopContext)
    {
        $this->globalShopContext = $globalShopContext;
    }

    public function set(string $id, $value, ?int $shopId = null)
    {
        if (!$shopId) {
            $shopId = $this->globalShopContext->getShopId();
        }

        PrestaShopConfiguration::updateValue($id, $value, false, null, $shopId);
    }

    /**
     * @return false|string|null
     */
    public function get(string $id, ?int $shopId = null)
    {
        if (!$shopId) {
            $shopId = $this->globalShopContext->getShopId();
        }

        $result = PrestaShopConfiguration::get($id, null, null, $shopId);

        return $result ?: null;
    }

    public function getAsBoolean(string $id, ?int $shopId = null)
    {
        if (!$shopId) {
            $shopId = $this->globalShopContext->getShopId();
        }

        $result = $this->get($id, $shopId);

        if (in_array($result, ['null', 'false', '0', null, false, 0], true)) {
            return false;
        }

        return (bool) $result;
    }

    public function getAsInteger(string $id, ?int $shopId = null)
    {
        $result = $this->get($id, $shopId);

        if (in_array($result, ['null', 'false', '0', null, false, 0], true)) {
            return 0;
        }

        return (int) $result;
    }

    /**
     * Removes by specific shop id.
     *
     * @param int $shopId
     */
    public function remove(string $id, ?int $shopId)
    {
        // making sure to set to null value only for single shop id
        $result = PrestaShopConfiguration::updateValue($id, null, false, null, $shopId);

        return (bool) $result;
    }

    /**
     * Drops configuration from all shops.
     */
    public function delete(string $id)
    {
        $result = PrestaShopConfiguration::deleteByName($id);

        return (bool) $result;
    }

    /**
     * @param string $key Configuration key
     * @param mixed $values $values is an array if the configuration is multilingual, a single string else
     * @param bool $html Specify if html is authorized in value
     * @param int $idShopGroup
     * @param int $idShop
     */
    public function updateValue($key, $values, $idShop = null, $html = false, $idShopGroup = null)
    {
        if (null === $idShop) {
            $shops = \Shop::getShops(true);
            foreach ($shops as $shop) {
                PrestaShopConfiguration::updateValue($key, $values, $html, $shop['id_shop_group'], $shop['id_shop']);
            }

            return;
        }

        PrestaShopConfiguration::updateValue($key, $values, $html, $idShopGroup, $idShop);
    }
}
