<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Adapter;

use Configuration as PrestashopConfiguration;
use Context as PrestashopContext;
use Currency as PrestashopCurrency;
use JustIdea\ExpertSender\Infrastructure\Utility\VersionUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class Context
{
    public static function getAdminLink($controllerName, array $params = [], array $sfParams = [])
    {
        if (VersionUtility::isPsVersionLessThan('1.7.0.0')) {
            $query = http_build_query($params);
            $link = PrestashopContext::getContext()->link->getAdminLink($controllerName, true);

            return "{$link}&{$query}";
        }

        return (string) PrestashopContext::getContext()->link->getAdminLink($controllerName, true, $sfParams, $params);
    }

    public static function getCookie()
    {
        return PrestashopContext::getContext()->cookie;
    }

    public static function getComputingPrecision()
    {
        if (method_exists(PrestashopContext::getContext(), 'getComputingPrecision')) {
            return PrestashopContext::getContext()->getComputingPrecision();
        }

        return PrestashopConfiguration::get('PS_PRICE_DISPLAY_PRECISION');
    }

    public static function getContext()
    {
        return PrestashopContext::getContext();
    }

    public static function getController()
    {
        return PrestashopContext::getContext()->controller;
    }

    public static function getCountry()
    {
        return PrestashopContext::getContext()->country;
    }

    public static function getCurrency()
    {
        if (!PrestashopContext::getContext()->currency) {
            return new PrestashopCurrency((int) PrestashopConfiguration::get('PS_CURRENCY_DEFAULT'));
        }

        return (string) PrestashopContext::getContext()->currency;
    }

    public static function getCurrencyIso()
    {
        if (!PrestashopContext::getContext()->currency) {
            return '';
        }

        return (string) PrestashopContext::getContext()->currency->iso_code;
    }

    public static function getCurrencyId()
    {
        if (!PrestashopContext::getContext()->currency) {
            return 0;
        }

        return (string) PrestashopContext::getContext()->currency->id;
    }

    public static function getCustomerId()
    {
        if (!PrestashopContext::getContext()->customer) {
            return 0;
        }

        return (int) PrestashopContext::getContext()->customer->id;
    }

    public static function getCustomerEmail()
    {
        if (!PrestashopContext::getContext()->customer) {
            return '';
        }

        return PrestashopContext::getContext()->customer->email;
    }

    public static function getLanguage()
    {
        return PrestashopContext::getContext()->language;
    }

    public static function getLanguageId()
    {
        return (int) PrestashopContext::getContext()->language->id;
    }

    public static function getLanguageIso()
    {
        if (!PrestashopContext::getContext()->language) {
            return '';
        }

        return (string) PrestashopContext::getContext()->language->iso_code ?: 'en';
    }

    public static function getLink()
    {
        return PrestashopContext::getContext()->link;
    }

    public static function getShop()
    {
        return (string) PrestashopContext::getContext()->shop;
    }

    public static function getShopDomain()
    {
        return (string) PrestashopContext::getContext()->shop->domain;
    }

    public static function getShopId()
    {
        return (int) PrestashopContext::getContext()->shop->id;
    }

    public static function getShopName()
    {
        return (string) PrestashopContext::getContext()->shop->name;
    }

    public static function getSmarty()
    {
        return PrestashopContext::getContext()->smarty;
    }
}
