<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Adapter;

use JustIdea\ExpertSender\Core\Config\Config;
use Validate as PrestashopValidate;

if (!defined('_PS_VERSION_')) {
    exit;
}

class Validate
{
    public static function isConfigName($key): bool
    {
        return (bool) PrestashopValidate::isConfigName($key);
    }

    /**
     * Check object validity.
     *
     * @param object $object Object to validate
     *
     * @return bool Validity is ok or not
     */
    public static function isLoadedObject($object): bool
    {
        return (bool) PrestashopValidate::isLoadedObject($object);
    }

    public static function isPhoneNumber($number): bool
    {
        return (bool) (preg_match('/^[+1-9][0-9. ()\/-]*$/', $number) && PrestashopValidate::isPhoneNumber($number));
    }

    /**
     * Check for date format.
     *
     * @param string $date Date to validate
     *
     * @return bool Validity is ok or not
     */
    public static function isDateFormat($date)
    {
        return (bool) preg_match('/^([0-9]{4})-((0?[0-9])|(1[0-2]))-((0?[0-9])|([1-2][0-9])|(3[01]))( [0-9]{2}:[0-9]{2}:[0-9]{2})?$/', $date);
    }

    /**
     * Check for date format.
     *
     * @param string $date Date to validate
     *
     * @return bool Validity is ok or not
     */
    public static function isDateTimeFormat($date)
    {
        return (bool) preg_match('/^([0-9]{4})-((0?[0-9])|(1[0-2]))-((0?[0-9])|([1-2][0-9])|(3[01])) ([0-9]{2}):([0-9]{2}):([0-9]{2})$/', $date);
    }

    /**
     * Check if the field is empty.
     *
     * @param string $field Date to validate
     *
     * @return bool Validity is ok or not
     */
    public static function isEmpty($field)
    {
        return $field === '' || $field === null;
    }

    /**
     * Validates the batch size value.
     *
     * @param int $batchSize the proposed batch size to validate
     *
     * @return bool Validity is ok or not
     */
    public static function isValidBatchSize(int $batchSize): bool
    {
        $batchSizes = Config::getBatchSizeValuesArray();

        return (bool) array_key_exists($batchSize, $batchSizes);
    }
}
