<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Controller\Admin;

use JustIdea\ExpertSender\Core\Config\Config;
use JustIdea\ExpertSender\Infrastructure\Enum\PermissionType;
use JustIdea\ExpertSender\Infrastructure\Utility\FieldsMappingUtility;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractAssociationAdminController extends AbstractAdminController
{
    public const FILE_NAME = 'AbstractAssociationAdminController';

    public function initContent()
    {
        if (!empty($this->errors)) {
            $this->display = 'edit';
        }

        parent::initContent();
    }

    public function postProcess()
    {
        if (\Tools::isSubmit('submitBulkdelete' . $this->table)) {
            if ($this->ensureHasPermissions([PermissionType::DELETE], false, true)) {
                $this->action = 'bulkdelete';
                $this->boxes = \Tools::getValue($this->table . 'Box');
                if (is_array($this->boxes) && array_key_exists(0, $this->boxes)) {
                    if (!$res = parent::postProcess(true)) {
                        return $res;
                    }
                    \Tools::redirectAdmin($this->context->link->getAdminLink(Config::ASSOCIATION_CONTROLLER) . '&conf=2&token=' . \Tools::getAdminTokenLite(Config::ASSOCIATION_CONTROLLER));
                }
            } else {
                $this->errors[] = $this->module->l('You do not have permission to delete this.', self::FILE_NAME);
            }
        } elseif (\Tools::isSubmit('submitBulkenableSelection' . $this->table)) {
            if ($this->ensureHasPermissions([PermissionType::EDIT], false, true)) {
                $this->action = 'bulkenableSelection';
                $this->boxes = \Tools::getValue($this->table . 'Box');
                if (is_array($this->boxes) && array_key_exists(0, $this->boxes)) {
                    if (!$res = parent::postProcess(true)) {
                        return $res;
                    }
                    \Tools::redirectAdmin($this->context->link->getAdminLink(Config::ASSOCIATION_CONTROLLER) . '&conf=5&token=' . \Tools::getAdminTokenLite(Config::ASSOCIATION_CONTROLLER));
                }
            } else {
                $this->errors[] = $this->module->l('You do not have permission to enable this.', self::FILE_NAME);
            }
        } elseif (\Tools::isSubmit('submitBulkdisableSelection' . $this->table)) {
            if ($this->ensureHasPermissions([PermissionType::EDIT], false, true)) {
                $this->action = 'bulkdisableSelection';
                $this->boxes = \Tools::getValue($this->table . 'Box');
                if (is_array($this->boxes) && array_key_exists(0, $this->boxes)) {
                    if (!$res = parent::postProcess(true)) {
                        return $res;
                    }
                    \Tools::redirectAdmin($this->context->link->getAdminLink(Config::ASSOCIATION_CONTROLLER) . '&conf=5&token=' . \Tools::getAdminTokenLite(Config::ASSOCIATION_CONTROLLER));
                }
            } else {
                $this->errors[] = $this->module->l('You do not have permission to disable this.', self::FILE_NAME);
            }
        } else {
            return parent::postProcess();
        }
    }

    public function renderList($fields_list = null)
    {
        $this->multiple_fieldsets = true;
        $this->show_sql_query = true;
        $this->actions_available = ['enable', 'disable', 'edit'];
        $this->list_no_link = true;
        $this->_use_found_rows = true;
        $this->display = 'list';

        $this->addRowAction('edit');
        $this->addRowAction('delete');

        $this->bulk_actions = [
            'delete' => [
                'text' => $this->module->l('Delete selected', self::FILE_NAME),
                'confirm' => $this->module->l('Delete selected items?', self::FILE_NAME),
                'icon' => 'icon-trash',
            ],
            'enableSelection' => [
                'text' => $this->module->l('Enable selection', self::FILE_NAME),
                'icon' => 'icon-power-off text-success',
            ],
            'disableSelection' => [
                'text' => $this->module->l('Disable selection', self::FILE_NAME),
                'icon' => 'icon-power-off text-danger',
            ],
        ];

        if (\Tools::isSubmit('submitFilter' . $this->list_id) || false !== $this->context->cookie->{'submitFilter' . $this->list_id} || \Tools::getValue($this->list_id . 'Orderby') || false !== $this->context->cookie->{$this->getCookieFilterPrefix() . $this->list_id . 'Orderby'} || \Tools::getValue($this->list_id . 'Orderway') || false !== $this->context->cookie->{$this->getCookieFilterPrefix() . $this->list_id . 'Orderway'}
        ) {
            $this->filter = true;
        }
        $this->action = (\Tools::getIsset('submitReset' . $this->table) ? 'reset_filters' : null);

        $this->_defaultOrderWay = 'ASC';

        $this->postProcess();

        $this->initToolbar();

        return parent::renderList();
    }

    public function renderForm($fields_form = null)
    {
        return parent::renderForm($fields_form);
    }

    // public function getFieldNameById($value, $row)
    // {
    //     $prestaConsentsRepository = $this->module->getService(ConsentsRepositoryInterface::class);
    //     /** @var ConsentsDataLines $prestaConsents */
    //     $prestaConsents = $prestaConsentsRepository->getConsents()->getConsentsDataLines();
    //     /** @var ConsentsDataLine $consent */
    //     $consent = $prestaConsents->getBy((new CollectionCriteria())->where('id', $value));

    //     if ($consent) {
    //         return $consent->getName();
    //     }

    //     return $this->module->l('Undefined', self::FILE_NAME);
    // }

    /**
     * Delete multiple items.
     *
     * @return bool true if success
     */
    // protected function processBulkDelete()
    // {
    //     $identifierList = \Tools::getValue($this->list_id . 'Box', []);

    //     if (is_array($identifierList) && !empty($identifierList)) {
    //         $object = new $this->className();

    //         if (isset($object->noZeroObject)) {
    //             $objects_count = count(call_user_func(array($this->className, $object->noZeroObject)));

    //             // Check if all object will be deleted
    //             if ($objects_count <= 1 || count($identifierList) == $objects_count) {
    //                 $this->errors[] = $this->module->l('You need at least one object.', self::FILE_NAME) .
    //                 ' <b>' . $this->table . '</b><br />' .
    //                 $this->module->l('You cannot delete all of the items.', self::FILE_NAME);
    //             }
    //         } else {
    //             $result = true;
    //             foreach ($identifierList as $id) {
    //                 /** @var $to_delete ObjectModel */
    //                 $to_delete = new $this->className($id);
    //                 $delete_ok = true;
    //                 if ($this->deleted) {
    //                     $to_delete->deleted = 1;
    //                     if (!$to_delete->update()) {
    //                         $result = false;
    //                         $delete_ok = false;
    //                     }
    //                 } elseif (!$to_delete->delete()) {
    //                     $result = false;
    //                     $delete_ok = false;
    //                 } elseif ($to_delete->id === null) {
    //                     $result = false;
    //                     $delete_ok = false;
    //                 }

    //                 if ($delete_ok) {
    //                     $this->module->getLogger()->info(sprintf($this->module->l('Deletion ID #%s of %s object class.', self::FILE_NAME), (int) $to_delete->id, $this->className), ['id_object' => (int) $to_delete->id, 'id_employee' => (int) $this->context->employee->id, 'class_object' => $this->className]);
    //                 } else {
    //                     $this->errors[] = sprintf($this->module->l('Can\'t delete #%s', self::FILE_NAME), $id);
    //                 }
    //             }
    //             if ($result) {
    //                 $this->redirect_after = $this->context->link->getAdminLink(Config::ASSOCIATION_CONTROLLER) . '&conf=2&token=' . \Tools::getAdminTokenLite(Config::ASSOCIATION_CONTROLLER);
    //             } else {
    //                 $this->redirect_after = $this->context->link->getAdminLink(Config::ASSOCIATION_CONTROLLER) . '&token=' . \Tools::getAdminTokenLite(Config::ASSOCIATION_CONTROLLER);
    //             }
    //             $this->errors[] = $this->module->l('An error occurred while deleting this selection.', self::FILE_NAME);
    //         }
    //     } else {
    //         $this->errors[] = $this->module->l('You must select at least one element to delete.', self::FILE_NAME);
    //     }

    //     if (isset($result)) {
    //         return $result;
    //     } else {
    //         return false;
    //     }
    // }

    public function getList($id_lang, $orderBy = null, $orderWay = null, $start = 0, $limit = null, $id_lang_shop = null)
    {
        parent::getList($id_lang, $orderBy, $orderWay, $start, $limit, $id_lang_shop);

        if ($this->_list) {
            foreach ($this->_list as &$row) {
                $row['field_name'] = $row['id_field'];
            }
        }
    }

    /**
     * Copy data values from $_POST to object.
     *
     * @param ObjectModel &$object Object
     * @param string $table Object table
     */
    protected function copyFromPost(&$object, $table)
    {
        parent::copyFromPost($object, $table);

        if (property_exists($object, 'fields_mapping')) {
            $object->{'fields_mapping'} = FieldsMappingUtility::serializeFieldsMapping(
                (int) \Tools::getValue('id_mapping_field'),
                (int) \Tools::getValue('id_mapping_field_value')
            );
        }
    }
}
