<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Controller\Admin;

use JustIdea\ExpertSender\Core\Config\Config;
use JustIdea\ExpertSender\Infrastructure\Enum\PermissionType;

if (!defined('_PS_VERSION_')) {
    exit;
}

class AjaxController extends AbstractAdminController
{
    public const FILE_NAME = 'AjaxController';

    /**
     * @var string
     */
    public $actionMethod;

    /**
     * @var string
     */
    public $secureKey;

    public function __construct()
    {
        parent::__construct();
    }

    public function postProcess()
    {
        $this->actionMethod = \Tools::getValue('method');
        $this->secureKey = \Tools::getValue('secure_key');

        if ($this->secureKey !== \Configuration::getGlobalValue(Config::AJAX_TOKEN)) {
            exit($this->module->l('Invalid secure_key.', self::FILE_NAME));
        }

        if (method_exists($this, $this->actionMethod . 'Action')) {
            call_user_func([$this, $this->actionMethod . 'Action']);
            exit;
        }

        exit($this->module->l('Unknown action.', self::FILE_NAME));
    }

    private function downloadCronjobManualAction()
    {
        if (!$this->ensureHasPermissions([PermissionType::VIEW], true)) {
            exit($this->module->l('You have no permission to see this.', self::FILE_NAME));
        }

        $employeeLanguageIso = \Language::getIsoById($this->context->employee->id_lang);
        $shopLanguageIso = $this->context->language->iso_code;

        $possibleLanguages = [$employeeLanguageIso, $shopLanguageIso, 'en'];
        $pdfFilePath = $this->findPDFPath($possibleLanguages);

        if ($pdfFilePath) {
            header('Content-Type: application/pdf');
            header('Content-Disposition: inline; filename="' . $this->module->l('How to setup a cron task', self::FILE_NAME) . '.pdf"'); // "attachment" to download or "inline" to display
            readfile($pdfFilePath);
            exit;
        }

        exit($this->module->l('Instruction file not found. It may have been deleted or moved. Please contact support.', self::FILE_NAME));
    }

    private function findPDFPath($languages)
    {
        foreach ($languages as $langIso) {
            $pdfFilePath = _PS_MODULE_DIR_ . $this->module->name . '/docs/cronmanual_' . \Tools::strtolower($langIso) . '.pdf';
            if (file_exists($pdfFilePath)) {
                return $pdfFilePath;
            }
        }

        return false;
    }
}
