<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Controller\Admin;

use JustIdea\ExpertSender\Core\Config\Config;

if (!defined('_PS_VERSION_')) {
    exit;
}

class SettingsController extends AbstractAdminController
{
    public const FILE_NAME = 'SettingsController';

    protected $spacer_size = '5';

    protected $apiParametres = [];

    protected $integrationParametres = [];

    public function __construct()
    {
        parent::__construct();

        $this->override_folder = '_override/';
        $this->tpl_folder = '_override/';

        $this->apiParametres = [
            Config::API_TOKEN,
        ];

        $this->integrationParametres = [
            Config::WEBSITE_ID,
        ];
    }

    public function initContent()
    {
        parent::initContent();

        $this->clearFieldsForm();
        $this->initApiSettingsForm();
        $this->context->smarty->assign('formApiSettings', $this->renderForm());

        $this->clearFieldsForm();
        $this->initIntegrationSettingsForm();
        $this->context->smarty->assign('formIntegrationSettings', $this->renderForm());

        $this->content = $this->context->smarty->fetch($this->getTemplatePath() . 'tabs/tab-settings.tpl');
        $this->context->smarty->assign('content', $this->content);
    }

    public function initProcess(): void
    {
        if (\Tools::isSubmit(Config::SETTINGS_PANEL_API_FORM_SUBMIT)) {
            if ($this->saveApiForm()) {
                $this->confirmations[] = $this->module->l('Successful update.', self::FILE_NAME);
            }
        }

        if (\Tools::isSubmit(Config::SETTINGS_PANEL_INTEGRATION_FORM_SUBMIT)) {
            if ($this->saveIntegrationForm()) {
                $this->confirmations[] = $this->module->l('Successful update.', self::FILE_NAME);
            }
        }

        parent::initProcess();
    }

    public function saveApiForm()
    {
        $result = true;

        foreach (\Tools::getAllValues() as $fieldName => $fieldValue) {
            if (in_array($fieldName, $this->apiParametres) && Config::API_TOKEN === $fieldName) {
                $currentToken = \Configuration::get(Config::API_TOKEN);

                if ($fieldValue !== str_repeat('*', strlen($currentToken))) {
                    $result &= \Configuration::updateValue(\Tools::strtoupper($fieldName), pSQL($fieldValue));
                }
                $result &= \Configuration::updateValue(Config::IS_API_TOKEN_VALID, 1);
            } elseif (in_array($fieldName, $this->apiParametres)) {
                $result &= \Configuration::updateValue(\Tools::strtoupper($fieldName), pSQL($fieldValue));
            }
        }

        return $result;
    }

    public function saveIntegrationForm()
    {
        $result = true;

        foreach (\Tools::getAllValues() as $fieldName => $fieldValue) {
            if (in_array($fieldName, $this->integrationParametres)) {
                $result &= \Configuration::updateValue(\Tools::strtoupper($fieldName), pSQL($fieldValue));
            }
        }

        return $result;
    }

    private function initApiSettingsForm()
    {
        $formFields = [
            [
                'type' => 'password',
                'name' => Config::API_TOKEN,
                'label' => $this->module->l('API Token', self::FILE_NAME),
                'prefix' => \Configuration::get(Config::API_TOKEN_PREFIX),
                'value' => \Tools::getIsset(Config::API_TOKEN) && false !== \Tools::getValue(Config::API_TOKEN) ? str_repeat('*', strlen(\Tools::getValue(Config::API_TOKEN))) : str_repeat('*', strlen(\Configuration::get(Config::API_TOKEN))),
                'cast' => 'strval',
                'auto_value' => false,
            ],
            [
                'type' => 'desc',
                'name' => Config::API_TOKEN . Config::CONST_STRING_DESCRPTION,
                'template' => Config::API_TOKEN . Config::CONST_STRING_DESCRPTION,
                'class' => '',
            ],
        ];

        $this->fields_form['form'] = [
            'form' => [
                'id_form' => Config::SETTINGS_API_CONFIG_FORM_NAME,
                'legend' => [
                    'title' => $this->module->l('API Settings', self::FILE_NAME),
                    'icon' => 'icon-cogs',
                ],
                'input' => $formFields,
                'submit' => [
                    'title' => $this->module->l('Save', self::FILE_NAME),
                    'name' => Config::SETTINGS_PANEL_API_FORM_SUBMIT,
                    'id' => Config::SETTINGS_PANEL_API_FORM_SUBMIT . 'SubmitBtn',
                    'class' => 'btn btn-default pull-right',
                    'icon' => 'process-icon-save',
                ],
            ],
        ];

        $values = [];
        foreach ($this->apiParametres as $parameter) {
            if (Config::API_TOKEN === $parameter) {
                $values[$parameter] = \Tools::getIsset($parameter) ? str_repeat('*', strlen(\Tools::getValue($parameter))) : str_repeat('*', strlen(\Configuration::get($parameter)));
            } else {
                $values[$parameter] = \Configuration::get(\Tools::strtoupper($parameter));
            }
        }
        $this->tpl_form_vars = array_merge($this->tpl_form_vars, $values);
    }

    private function initIntegrationSettingsForm()
    {
        $formFields = [
            [
                'type' => 'text',
                'name' => Config::WEBSITE_ID,
                'label' => $this->module->l('Website ID', self::FILE_NAME),
                'cast' => 'strval',
            ],
            [
                'type' => 'desc',
                'name' => Config::WEBSITE_ID . Config::CONST_STRING_DESCRPTION,
                'template' => Config::WEBSITE_ID . Config::CONST_STRING_DESCRPTION,
                'class' => '',
            ],
        ];

        $this->fields_form['form'] = [
            'form' => [
                'id_form' => Config::SETTINGS_INTEGRATION_CONFIG_FORM_NAME,
                'legend' => [
                    'title' => $this->module->l('Integration Settings', self::FILE_NAME),
                    'icon' => 'icon-building',
                ],
                'input' => $formFields,
                'submit' => [
                    'title' => $this->module->l('Save', self::FILE_NAME),
                    'name' => Config::SETTINGS_PANEL_INTEGRATION_FORM_SUBMIT,
                    'id' => Config::SETTINGS_PANEL_INTEGRATION_FORM_SUBMIT . 'SubmitBtn',
                    'class' => 'btn btn-default pull-right',
                    'icon' => 'process-icon-save',
                ],
            ],
        ];

        $values = [];
        foreach ($this->integrationParametres as $parameter) {
            $values[$parameter] = \Configuration::get(\Tools::strtoupper($parameter));
        }
        $this->tpl_form_vars = array_merge($this->tpl_form_vars, $values);
    }
}
