<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Database\Exception;

use JustIdea\ExpertSender\Infrastructure\Enum\ExceptionCode;
use JustIdea\ExpertSender\Infrastructure\Exception\ExpertSenderException;

if (!defined('_PS_VERSION_')) {
    exit;
}

final class CouldNotInstallModule extends ExpertSenderException
{
    public static function failedToInstallConfiguration($configurationName, $configurationValue, ?\Exception $exception = null): CouldNotInstallModule
    {
        return new self(
            sprintf('Failed to install configuration ("%1$s" => "%2$s")', $configurationName, $configurationValue),
            ExceptionCode::INFRASTRUCTURE_FAILED_TO_INSTALL_CONFIGURATION,
            $exception,
            [
                'configuration_name' => $configurationName,
                'configuration_value' => $configurationValue,
            ]
        );
    }

    public static function failedToInstallDatabaseTable($databaseTable, ?\Exception $exception = null): CouldNotInstallModule
    {
        return new self(
            sprintf('Failed to install database table (%s)', $databaseTable),
            ExceptionCode::INFRASTRUCTURE_FAILED_TO_INSTALL_DATABASE_TABLE,
            $exception,
            [
                'database_table' => $databaseTable,
            ]
        );
    }

    public static function failedToInstallHook($hookName, ?\Exception $exception = null): CouldNotInstallModule
    {
        return new self(
            sprintf('Failed to install hook (%s)', $hookName),
            ExceptionCode::INFRASTRUCTURE_FAILED_TO_INSTALL_HOOK,
            null,
            [
                'hook_name' => $hookName,
            ]
        );
    }

    public static function failedToInstallModuleTab(string $moduleTab, ?\Exception $exception = null): self
    {
        return new self(
            sprintf('Failed to install module tab (%s)', $moduleTab),
            ExceptionCode::INFRASTRUCTURE_FAILED_TO_INSTALL_MODULE_TAB,
            $exception,
            [
                'module_tab' => $moduleTab,
            ]
        );
    }
}
