<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Database\Install\Command;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ExpertSenderOrderStateMappingTableInstallCommand implements InstallCommandInterface
{
    public function getName(): string
    {
        return \ExpertSenderOrderStateMapping::$definition['table'];
    }

    public function getCommand(): string
    {
        return 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . pSQL(\ExpertSenderOrderStateMapping::$definition['table']) . '` (
                `id_order_state_mapping` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
                `id_field` INT(11) UNSIGNED NULL,
                `id_expertsender_field` INT(11) UNSIGNED NULL,
                `expertsender_field_name` CHAR(255) NOT NULL,
                `fields_mapping` LONGTEXT NOT NULL,
                `active` TINYINT(1) NOT NULL DEFAULT 1,
                `mapping_name` CHAR(64) NOT NULL,
            PRIMARY KEY (`id_order_state_mapping`),
            UNIQUE KEY (`id_expertsender_field`),
            INDEX `idx_id_order_state_mapping` (`id_order_state_mapping`),
            INDEX `idx_id_field` (`id_field`),
            INDEX `idx_id_expertsender_field` (`id_expertsender_field`),
            INDEX `idx_active` (`active`)
        ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;';
    }
}
