<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Database\Install;

use JustIdea\ExpertSender\Infrastructure\Database\Exception\CouldNotInstallModule;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderConsentMappingTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderCustomerConsentTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderCustomerMappingTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderCustomersTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderLogsTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderOrderMappingTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderOrdersTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderOrderStateMappingRelationTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderOrderStateMappingTableInstallCommand;
use JustIdea\ExpertSender\Infrastructure\Database\Install\Command\ExpertSenderProductMappingTableInstallCommand;

if (!defined('_PS_VERSION_')) {
    exit;
}

class DatabaseTableInstaller implements InstallerInterface
{
    /**
     * @var ExpertSenderLogsTableInstallCommand
     */
    private $expertSenderLogsTableInstallCommand;

    /**
     * @var ExpertSenderOrdersTableInstallCommand
     */
    private $expertSenderOrdersTableInstallCommand;

    /**
     * @var ExpertSenderCustomersTableInstallCommand
     */
    private $expertSenderCustomersTableInstallCommand;

    /**
     * @var ExpertSenderConsentMappingTableInstallCommand
     */
    private $expertSenderConsentMappingTableInstallCommand;

    /**
     * @var ExpertSenderCustomerConsentTableInstallCommand
     */
    private $expertSenderCustomerConsentTableInstallCommand;

    /**
     * @var ExpertSenderCustomerMappingTableInstallCommand
     */
    private $expertSenderCustomerMappingTableInstallCommand;

    /**
     * @var ExpertSenderOrderMappingTableInstallCommand
     */
    private $expertSenderOrderMappingTableInstallCommand;

    /**
     * @var ExpertSenderOrderStateMappingTableInstallCommand
     */
    private $expertSenderOrderStateMappingTableInstallCommand;

    /**
     * @var ExpertSenderOrderStateMappingRelationTableInstallCommand
     */
    private $expertSenderOrderStateMappingRelationTableInstallCommand;

    /**
     * @var ExpertSenderProductMappingTableInstallCommand
     */
    private $expertSenderProductMappingTableInstallCommand;

    public function __construct(
        ExpertSenderLogsTableInstallCommand $expertSenderLogsTableInstallCommand,
        ExpertSenderOrdersTableInstallCommand $expertSenderOrdersTableInstallCommand,
        ExpertSenderCustomersTableInstallCommand $expertSenderCustomersTableInstallCommand,
        ExpertSenderConsentMappingTableInstallCommand $expertSenderConsentMappingTableInstallCommand,
        ExpertSenderCustomerConsentTableInstallCommand $expertSenderCustomerConsentTableInstallCommand,
        ExpertSenderCustomerMappingTableInstallCommand $expertSenderCustomerMappingTableInstallCommand,
        ExpertSenderOrderMappingTableInstallCommand $expertSenderOrderMappingTableInstallCommand,
        ExpertSenderOrderStateMappingTableInstallCommand $expertSenderOrderStateMappingTableInstallCommand,
        ExpertSenderOrderStateMappingRelationTableInstallCommand $expertSenderOrderStateMappingRelationTableInstallCommand,
        ExpertSenderProductMappingTableInstallCommand $expertSenderProductMappingTableInstallCommand
    ) {
        $this->expertSenderLogsTableInstallCommand = $expertSenderLogsTableInstallCommand;
        $this->expertSenderOrdersTableInstallCommand = $expertSenderOrdersTableInstallCommand;
        $this->expertSenderCustomersTableInstallCommand = $expertSenderCustomersTableInstallCommand;
        $this->expertSenderConsentMappingTableInstallCommand = $expertSenderConsentMappingTableInstallCommand;
        $this->expertSenderCustomerConsentTableInstallCommand = $expertSenderCustomerConsentTableInstallCommand;
        $this->expertSenderCustomerMappingTableInstallCommand = $expertSenderCustomerMappingTableInstallCommand;
        $this->expertSenderOrderMappingTableInstallCommand = $expertSenderOrderMappingTableInstallCommand;
        $this->expertSenderOrderStateMappingTableInstallCommand = $expertSenderOrderStateMappingTableInstallCommand;
        $this->expertSenderOrderStateMappingRelationTableInstallCommand = $expertSenderOrderStateMappingRelationTableInstallCommand;
        $this->expertSenderProductMappingTableInstallCommand = $expertSenderProductMappingTableInstallCommand;
    }

    /** {@inheritDoc} */
    public function init(): void
    {
        $commands = $this->getCommands();

        foreach ($commands as $command) {
            if (false == \Db::getInstance()->execute($command->getCommand())) {
                throw CouldNotInstallModule::failedToInstallDatabaseTable($command->getName());
            }
        }
    }

    /**
     * @return InstallCommandInterface[]
     */
    private function getCommands(): array
    {
        return [
            $this->expertSenderLogsTableInstallCommand,
            $this->expertSenderOrdersTableInstallCommand,
            $this->expertSenderCustomersTableInstallCommand,
            $this->expertSenderConsentMappingTableInstallCommand,
            $this->expertSenderCustomerConsentTableInstallCommand,
            $this->expertSenderCustomerMappingTableInstallCommand,
            $this->expertSenderOrderMappingTableInstallCommand,
            $this->expertSenderOrderStateMappingTableInstallCommand,
            $this->expertSenderOrderStateMappingRelationTableInstallCommand,
            $this->expertSenderProductMappingTableInstallCommand,
        ];
    }
}
