<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Database\Install;

use JustIdea\ExpertSender\Infrastructure\Database\Exception\CouldNotInstallModule;

if (!defined('_PS_VERSION_')) {
    exit;
}

class Installer implements InstallerInterface
{
    public const CLASS_NAME = 'Installer';

    /**
     * @var ConfigurationInstaller
     */
    private $configurationInstaller;

    /**
     * @var DatabaseTableInstaller
     */
    private $databaseTableInstaller;

    /**
     * @var HookInstaller
     */
    private $hookInstaller;

    /**
     * @var ModuleTabInstaller
     */
    private $moduleTabInstaller;

    public function __construct(
        ConfigurationInstaller $configurationInstaller,
        DatabaseTableInstaller $databaseTableInstaller,
        HookInstaller $hookInstaller,
        ModuleTabInstaller $moduleTabInstaller
    ) {
        $this->configurationInstaller = $configurationInstaller;
        $this->databaseTableInstaller = $databaseTableInstaller;
        $this->hookInstaller = $hookInstaller;
        $this->moduleTabInstaller = $moduleTabInstaller;
    }

    /**
     * @throws CouldNotInstallModule
     */
    public function init(): void
    {
        try {
            $this->configurationInstaller->init();
            $this->databaseTableInstaller->init();
            $this->hookInstaller->init();
            $this->moduleTabInstaller->init();

            if (method_exists(\Tools::class, 'clearCache')) {
                \Tools::clearCache();
            }
        } catch (CouldNotInstallModule $exception) {
            throw $exception;
        } catch (\Throwable $exception) {
            throw CouldNotInstallModule::unknownError($exception);
        }
    }
}
