<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Database\Uninstall;

use JustIdea\ExpertSender\Infrastructure\Adapter\Tab;
use JustIdea\ExpertSender\Infrastructure\Database\Exception\CouldNotUninstallModule;
use JustIdea\ExpertSender\Infrastructure\Database\ModuleTabs;
use JustIdea\ExpertSender\Infrastructure\EntityManager\EntityManagerInterface;
use JustIdea\ExpertSender\Infrastructure\EntityManager\ObjectModelUnitOfWork;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ModuleTabUninstaller implements UninstallerInterface
{
    /**
     * @var Tab
     */
    private $tab;

    /**
     * @var ModuleTabs
     */
    private $moduleTabs;

    /**
     * @var EntityManagerInterface
     */
    private $entityManager;

    public function __construct(
        Tab $tab,
        ModuleTabs $moduleTabs,
        EntityManagerInterface $entityManager
    ) {
        $this->tab = $tab;
        $this->moduleTabs = $moduleTabs;
        $this->entityManager = $entityManager;
    }

    /**
     * @throws CouldNotUninstallModule
     */
    public function init(): void
    {
        $tabs = $this->moduleTabs->getTabs();

        foreach ($tabs as $tab) {
            if (!($tabId = $this->tab->getIdFromClassName($tab['class_name']))) {
                continue;
            }

            $this->uninstallTab($tab['class_name'], $tabId);
        }
    }

    /**
     * @throws CouldNotUninstallModule
     */
    private function uninstallTab(string $className, int $tabId): void
    {
        $moduleTab = $this->tab->initTab($tabId);

        try {
            if (\Validate::isLoadedObject($moduleTab)) {
                $this->entityManager->persist($moduleTab, ObjectModelUnitOfWork::UNIT_OF_WORK_DELETE);
                $this->entityManager->flush();
            }
        } catch (\Exception $exception) {
            throw CouldNotUninstallModule::failedToUninstallModuleTab($className, $exception);
        }
    }
}
