<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\EntityManager;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ObjectModelEntityManager implements EntityManagerInterface
{
    /**
     * @var ObjectModelUnitOfWork
     */
    private $unitOfWork;

    public function __construct(ObjectModelUnitOfWork $unitOfWork)
    {
        $this->unitOfWork = $unitOfWork;
    }

    /**
     * @param string $unitOfWorkType
     * @param string|null $specificKey - for example external_id key to make it easier to keep track of which object model is related to which external_id
     */
    public function persist(
        \ObjectModel $model,
        $unitOfWorkType,
        $specificKey = null
    ) {
        $this->unitOfWork->setWork($model, $unitOfWorkType, $specificKey);

        return $this;
    }

    /**
     * @return array<ObjectModel>
     *
     * @throws \PrestaShopDatabaseException
     * @throws \PrestaShopException
     */
    public function flush()
    {
        $persistenceModels = $this->unitOfWork->getWork();
        $persistedModels = [];

        try {
            foreach ($persistenceModels as $externalId => $persistenceModel) {
                if (ObjectModelUnitOfWork::UNIT_OF_WORK_SAVE === $persistenceModel['unit_of_work_type']) {
                    $persistenceModel['object']->save();
                }

                if (ObjectModelUnitOfWork::UNIT_OF_WORK_DELETE === $persistenceModel['unit_of_work_type']) {
                    $persistenceModel['object']->delete();
                }

                if (!empty($externalId)) {
                    $persistedModels[$externalId] = $persistenceModel['object'];
                } else {
                    $persistedModels[] = $persistenceModel['object'];
                }
            }
            $this->unitOfWork->clearWork();
        } catch (\Throwable $th) {
            $this->unitOfWork->clearWork();
            throw $th;
        }

        return $persistedModels;
    }
}
