<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Hook;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractHook implements HookInterface
{
    public const FILE_NAME = 'AbstractHook';

    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    protected $module;

    /**
     * @var Context
     */
    protected $context;

    /**
     * @param \ExpertSenderOfficial $module
     */
    public function __construct(\ExpertSenderOfficial $module)
    {
        $this->module = $module;
        $this->context = \Context::getContext();
    }

    final public function exec(array &$params = [])
    {
        try {
            $result = $this->executeHook($params);

            return $result;
        } catch (\Exception $exception) {
            $this->module->getLogger()->error($this->module->l('Hook execution failed', self::FILE_NAME), [
                'hook_name' => static::class,
                'params' => $params,
                'exception' => $exception->getMessage(),
            ]);

            return null;
        }
    }

    abstract protected function executeHook(array &$params = []);

    /**
     * @param array $data
     *
     * @return string
     */
    protected function encodeData(array $data): string
    {
        return rawurlencode(json_encode($data, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
}
