<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectCustomerDeleteAfter;

use JustIdea\ExpertSender\Core\Customer\Action\DeleteCustomerConsentObjectAction;
use JustIdea\ExpertSender\Core\Customer\Action\DeleteCustomerObjectAction;
use JustIdea\ExpertSender\Core\Customer\DTO\DeleteCustomerConsentObjectRequestData;
use JustIdea\ExpertSender\Core\Customer\DTO\DeleteCustomerObjectRequestData;
use JustIdea\ExpertSender\Infrastructure\Adapter\Validate;
use JustIdea\ExpertSender\Infrastructure\Hook\AbstractHook;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractActionObjectCustomerDeleteAfterHook extends AbstractHook
{
    /**
     * @var array
     */
    protected $params = [];

    public function executeHook(array &$params = [])
    {
        $this->params = $params;

        if ($this->isValidCustomerRequest()) {
            $this->deleteCustomerFromDatabase((int) $this->params['object']->id);
            $this->deleteCustomerConsentFromDatabase((int) $this->params['object']->id);
        }
    }

    /**
     * @return bool
     */
    protected function isValidCustomerRequest(): bool
    {
        return is_array($this->params)
        && isset($this->params['object'])
        && $this->params['object'] instanceof \CustomerCore
        && $this->params['object']->id
        && Validate::isLoadedObject($this->params['object']);
    }

    /**
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function deleteCustomerFromDatabase(int $customerId)
    {
        $deleteCustomerObjectAction = $this->module->getService(DeleteCustomerObjectAction::class);

        $deleteCustomerObjectAction->run(DeleteCustomerObjectRequestData::create(
            $customerId
        ));
    }

    /**
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function deleteCustomerConsentFromDatabase(int $customerId)
    {
        $deleteCustomerConsentObjectAction = $this->module->getService(DeleteCustomerConsentObjectAction::class);

        $deleteCustomerConsentObjectAction->run(DeleteCustomerConsentObjectRequestData::create(
            $customerId
        ));
    }
}
