<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectOrderDetailUpdateAfter;

use JustIdea\ExpertSender\Core\Order\Action\UpdateOrderSyncedFlagAction;
use JustIdea\ExpertSender\Core\Order\DTO\UpdateOrderSyncedFlagRequestData;
use JustIdea\ExpertSender\Infrastructure\Adapter\Validate;
use JustIdea\ExpertSender\Infrastructure\Hook\AbstractHook;

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class AbstractActionObjectOrderDetailUpdateAfterHook extends AbstractHook
{
    /**
     * @var array
     */
    protected $params = [];

    public function executeHook(array &$params = [])
    {
        $this->params = $params;

        if ($this->isValidOrderDetailRequest()) {
            $this->storeOrderIntoDatabase((int) $this->params['object']->id_order);
        }
    }

    /**
     * @return bool
     */
    protected function isValidOrderDetailRequest(): bool
    {
        return is_array($this->params)
        && isset($this->params['object'])
        && $this->params['object'] instanceof \OrderDetailCore
        && $this->params['object']->id_order_detail
        && $this->params['object']->id_order
        && Validate::isLoadedObject($this->params['object']);
    }

    /**
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     * @throws Exception
     */
    protected function storeOrderIntoDatabase(int $orderId)
    {
        $updateOrderSyncedFlagAction = $this->module->getService(UpdateOrderSyncedFlagAction::class);

        $updateOrderSyncedFlagAction->run(UpdateOrderSyncedFlagRequestData::create(
            $orderId,
            UpdateOrderSyncedFlagRequestData::TO_SYNC
        ));
    }
}
