<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Hook;

use JustIdea\ExpertSender\Infrastructure\Hook\ActionFrontControllerSetMedia\ActionFrontControllerSetMediaHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectAddressAddAfter\ActionObjectAddressAddAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectAddressDeleteAfter\ActionObjectAddressDeleteAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectAddressUpdateAfter\ActionObjectAddressUpdateAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectCustomerAddAfter\ActionObjectCustomerAddAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectCustomerDeleteAfter\ActionObjectCustomerDeleteAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectCustomerUpdateAfter\ActionObjectCustomerUpdateAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectCustomerUpdateBefore\ActionObjectCustomerUpdateBeforeHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectExpertSenderOrderStateMappingAddAfter\ActionObjectExpertSenderOrderStateMappingAddAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectExpertSenderOrderStateMappingUpdateAfter\ActionObjectExpertSenderOrderStateMappingUpdateAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectOrderAddAfter\ActionObjectOrderAddAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectOrderDeleteAfter\ActionObjectOrderDeleteAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectOrderDetailUpdateAfter\ActionObjectOrderDetailUpdateAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionObjectOrderUpdateAfter\ActionObjectOrderUpdateAfterHook;
use JustIdea\ExpertSender\Infrastructure\Hook\ActionProductCancel\ActionProductCancelHook;

if (!defined('_PS_VERSION_')) {
    exit;
}

class HookFactory extends AbstractHookFactory
{
    /**
     * @return HookInterface
     */
    protected function createActionObjectAddressAddAfterHook(): HookInterface
    {
        return new ActionObjectAddressAddAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectAddressDeleteAfterHook(): HookInterface
    {
        return new ActionObjectAddressDeleteAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectAddressUpdateAfterHook(): HookInterface
    {
        return new ActionObjectAddressUpdateAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectCustomerAddAfterHook(): HookInterface
    {
        return new ActionObjectCustomerAddAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectCustomerDeleteAfterHook(): HookInterface
    {
        return new ActionObjectCustomerDeleteAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectCustomerUpdateAfterHook(): HookInterface
    {
        return new ActionObjectCustomerUpdateAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectCustomerUpdateBeforeHook(): HookInterface
    {
        return new ActionObjectCustomerUpdateBeforeHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectOrderAddAfterHook(): HookInterface
    {
        return new ActionObjectOrderAddAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectOrderDeleteAfterHook(): HookInterface
    {
        return new ActionObjectOrderDeleteAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectOrderUpdateAfterHook(): HookInterface
    {
        return new ActionObjectOrderUpdateAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectOrderDetailUpdateAfterHook(): HookInterface
    {
        return new ActionObjectOrderDetailUpdateAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionProductCancelHook(): HookInterface
    {
        return new ActionProductCancelHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectExpertSenderOrderStateMappingAddAfterHook(): HookInterface
    {
        return new ActionObjectExpertSenderOrderStateMappingAddAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionObjectExpertSenderOrderStateMappingUpdateAfterHook(): HookInterface
    {
        return new ActionObjectExpertSenderOrderStateMappingUpdateAfterHook($this->module);
    }

    /**
     * @return HookInterface
     */
    protected function createActionFrontControllerSetMediaHook(): HookInterface
    {
        return new ActionFrontControllerSetMediaHook($this->module);
    }
}
