<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Logger\Export;

use JustIdea\ExpertSender\Infrastructure\Adapter\ModuleFactory;

if (!defined('_PS_VERSION_')) {
    exit;
}

class LogZipExportService implements LogZipExportServiceInterface
{
    /**
     * @var \ModuleCore&\Module&\ExpertSenderOfficial
     */
    private $module;

    /**
     * @var string
     */
    private $logsDir;

    public function __construct(ModuleFactory $moduleFactory)
    {
        $this->module = $moduleFactory->getModule();
        $this->logsDir = _PS_MODULE_DIR_ . $this->module->name . '/logs/';
    }

    public function exportToZip($filename, $dir = ''): bool
    {
        $zip = new \ZipArchive();
        $zipPath = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $filename;
        $fileAdded = false;

        if ($zip->open($zipPath, \ZipArchive::CREATE) === true) {
            $files = new \RecursiveIteratorIterator(
                new \RecursiveDirectoryIterator($this->logsDir),
                \RecursiveIteratorIterator::LEAVES_ONLY
            );

            foreach ($files as $file) {
                if (!$file->isDir() && pathinfo($file->getFilename(), PATHINFO_EXTENSION) == 'log') {
                    $filePath = $file->getRealPath();
                    $relativePath = substr($filePath, strlen($this->logsDir));

                    $zip->addFile($filePath, $relativePath);
                    $fileAdded = true;
                }
            }

            $zip->close();

            if ($fileAdded) {
                header('Content-Type: application/zip');
                header('Content-Disposition: attachment; filename="' . basename($zipPath) . '"');
                header('Content-Length: ' . filesize($zipPath));

                readfile($zipPath);
            }

            @unlink($zipPath);

            return $fileAdded;
        }
    }
}
