<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Logger\Formatter;

use JustIdea\ExpertSender\Infrastructure\Logger\ReportLogger;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ReportLogFormatter implements ReportLogFormatterInterface
{
    public const SEVERITY_INFO = 'INFO';
    public const SEVERITY_SUCCESS = 'SUCCESS';
    public const SEVERITY_WARNING = 'WARNING';
    public const SEVERITY_ERROR = 'ERROR';
    public const SEVERITY_CRITICAL = 'CRITICAL';

    public function writeMessage(int $level, string $message)
    {
        switch ($level) {
            case ReportLogger::SEVERITY_CRITICAL:
                $badge = self::SEVERITY_CRITICAL;
                break;

            case ReportLogger::SEVERITY_ERROR:
                $badge = self::SEVERITY_ERROR;
                break;

            case ReportLogger::SEVERITY_WARNING:
                $badge = self::SEVERITY_WARNING;
                break;

            case ReportLogger::SEVERITY_SUCCESS:
                $badge = self::SEVERITY_SUCCESS;
                break;

            default:
                $badge = self::SEVERITY_INFO;
                break;
        }

        $time = date('Y-m-d H:i:s');

        return "[$time] $badge: $message \n";
    }

    /**
     * @param string $message - an actual log message
     *
     * @return string
     */
    public function readMessage(string $message)
    {
        $pattern = '/\[(.*?)\] (' . self::SEVERITY_INFO . '|' . self::SEVERITY_SUCCESS . '|' . self::SEVERITY_WARNING . '|' . self::SEVERITY_ERROR . '|' . self::SEVERITY_CRITICAL . '): (.*)/';
        if (preg_match($pattern, $message, $matches)) {
            $time = $matches[1];
            $level = $matches[2];
            $text = $matches[3];

            switch ($level) {
                case self::SEVERITY_CRITICAL:
                    $badgeClass = 'badge-danger';
                    break;
                case self::SEVERITY_ERROR:
                    $badgeClass = 'badge-danger';
                    break;
                case self::SEVERITY_WARNING:
                    $badgeClass = 'badge-warning';
                    break;
                case self::SEVERITY_SUCCESS:
                    $badgeClass = 'badge-success';
                    break;
                default:
                    $badgeClass = 'badge-info';
                    break;
            }

            return "[$time] <span class=\"badge {$badgeClass}\">{$level}</span> {$text}";
        }

        return "$message";
    }
}
