<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Logger;

if (!defined('_PS_VERSION_')) {
    exit;
}

interface ReportLoggerInterface extends LoggerInterface
{
    /**
     * Retrieve session log file contents as an array.
     *
     * @param string $title optional title to filter logs
     * @param bool $format whether to format the output
     *
     * @return array<string> the contents of the log file as an array
     */
    public function getSessionLogFileContentsAsArray(string $title = '', bool $format = true): array;

    /**
     * Retrieve session log file contents as a string.
     *
     * @param string $title optional title to filter logs
     * @param bool $format whether to format the output
     *
     * @return string the contents of the log file as a string
     */
    public function getSessionLogFileContentsAsString(string $title = '', bool $format = true): string;

    /**
     * Retrieve log file contents as an array.
     *
     * @param string $title optional title to filter logs
     * @param bool $format whether to format the output
     *
     * @return array<string> the contents of the log file as an array
     */
    public function getLogFileContentsAsArray(string $title = '', bool $format = true): array;

    /**
     * Retrieve log file contents as a string.
     *
     * @param string $title optional title to filter logs
     * @param bool $format whether to format the output
     *
     * @return string the contents of the log file as a string
     */
    public function getLogFileContentsAsString(string $title = '', bool $format = true): string;

    /**
     * Archive session logs to a daily log file.
     *
     * @return bool true if the operation was successful, false otherwise
     */
    public function archiveSessionLogs(): bool;

    /**
     * Append a line break to the session log file.
     *
     * @return bool true if successful, false otherwise
     */
    public function appendSessionLogFileWithLineBreak(): bool;

    /**
     * Append a line break to the log file.
     *
     * @return bool true if successful, false otherwise
     */
    public function appendLogFileWithLineBreak(): bool;

    /**
     * Log a success event.
     *
     * @param string $message the message to log
     * @param mixed[] $context additional context for the log
     *
     * @return void
     */
    public function success($message, array $context = []);
}
