<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Logger\Repository;

use JustIdea\ExpertSender\Infrastructure\Repository\CollectionRepository;

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * Interface for retrieving log data from the database
 */
class LogRepository extends CollectionRepository implements LogRepositoryInterface
{
    /**
     * Database instance.
     *
     * @var \Db
     */
    private $db;

    /**
     * Log table name.
     *
     * @var string
     */
    private $logTable;

    public function __construct()
    {
        parent::__construct(\ExpertSenderLog::class);

        $this->db = \Db::getInstance();
        $this->logTable = \ExpertSenderLog::$definition['table'];
    }

    /**
     * Find a log by its ID.
     *
     * @param int $id the ID of the log to be found
     *
     * @return array|bool|object|null the log data if found, otherwise null
     */
    public function findById(int $id)
    {
        $query = new \DbQuery();
        $query->select('l.*')
            ->from($this->logTable, 'l')
            ->where('l.id_log = ' . (int) $id);

        return $this->db->getRow($query);
    }

    /**
     * Find all logs.
     *
     * @return array|false|\mysqli_result|\PDOStatement|resource|null
     */
    public function findAll()
    {
        $query = new \DbQuery();
        $query->select('l.*')
            ->from($this->logTable, 'l');

        return $this->db->executeS($query);
    }

    /**
     * Delete all logs.
     *
     * @return int the number of logs deleted
     */
    public function deleteAll(): int
    {
        $affectedRows = 0;

        $sql = 'DELETE ps_log FROM ' . _DB_PREFIX_ . 'log ps_log
                INNER JOIN ' . pSQL(_DB_PREFIX_ . $this->logTable) . ' es_log ON ps_log.id_log = es_log.id_log';

        if ($this->db->execute($sql)) {
            $affectedRows = $this->db->Affected_Rows();
            $this->db->delete($this->logTable);
        }

        return $affectedRows;
    }
}
