<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Logger\Writer;

use JustIdea\ExpertSender\Core\Config\Config;
use JustIdea\ExpertSender\Infrastructure\Logger\Formatter\ReportLogFormatterInterface;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ReportLogWriter implements ReportLogWriterInterface
{
    public const LOG_OBJECT_TYPE = 'expertsenderlog';
    private const NEW_LINE = '====================================';

    /**
     * @var ReportLogFormatterInterface
     */
    private $logFormatter;

    public function __construct(
        ReportLogFormatterInterface $logFormatter
    ) {
        $this->logFormatter = $logFormatter;
    }

    /**
     * @param string $filename - log filename
     * @param int $level - log level
     * @param string $message - an actual error message
     *
     * @return bool $result - bool if log was added
     */
    public function addLog(string $filename, int $level, string $message): bool
    {
        file_put_contents(
            $filename,
            $this->logFormatter->writeMessage($level, $message),
            FILE_APPEND
        );

        return true;
    }

    /**
     * @param string $filename - log filename
     *
     * @return bool $result - bool if a line break was added
     */
    public function addLineBreak(string $filename): bool
    {
        $newLine = self::NEW_LINE;

        file_put_contents(
            $filename,
            "$newLine\n",
            FILE_APPEND
        );

        return true;
    }

    /**
     * @param string $filename - log filename
     *
     * @return bool $result - bool if log was added
     */
    public function archiveSessionLogsToDailyLogs(string $filename, string $dailyLogsFileName): bool
    {
        if (!file_exists($filename)) {
            return false;
        }

        $sessionLogs = \Tools::file_get_contents($filename);

        if (empty($sessionLogs)) {
            return false;
        }

        if (\Configuration::get(Config::LOGS_REPORT_STORE_ENABLED)) {
            file_put_contents($dailyLogsFileName, "$sessionLogs", FILE_APPEND);
        }

        unlink($filename);

        return true;
    }
}
