<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Processor;

use JustIdea\ExpertSender\Infrastructure\Action\RemoveLogFilesAction;

if (!defined('_PS_VERSION_')) {
    exit;
}

class RemoveLogFilesProcessor implements RemoveLogFilesProcessorInterface
{
    public const FILE_NAME = 'RemoveLogFilesProcessor';

    /**
     * @var RemoveLogFilesAction The action responsible for removing log files
     */
    private $removeLogFilesAction;

    /**
     * Constructs a new RemoveLogFilesProcessor instance.
     *
     * @param RemoveLogFilesAction $removeLogFilesAction The action responsible for removing log files
     */
    public function __construct(
        RemoveLogFilesAction $removeLogFilesAction
    ) {
        $this->removeLogFilesAction = $removeLogFilesAction;
    }

    /**
     * Process the action of removing log files.
     *
     * @param array $settings Additional settings for the action (optional)
     *
     * @return string The result of the action execution
     */
    public function processAction($settings = []): string
    {
        return $this->removeLogFilesAction->run();
    }
}
