<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

namespace JustIdea\ExpertSender\Infrastructure\Request;

use Symfony\Component\HttpFoundation\Request as BaseRequest;

if (!defined('_PS_VERSION_')) {
    exit;
}

class Request extends BaseRequest
{
    /**
     * Returns the parameters.
     *
     * @return array An array of parameters
     */
    public function all(): array
    {
        return $this->request->all() + $this->query->all() + (json_decode((string) \Tools::file_get_contents('php://input'), true) ?? []) + $this->files->all();
    }

    /**
     * Retrieves a request parameter by name.
     *
     * @param string $key The name of the parameter
     * @param mixed $default The default value to return if the parameter is not found
     * @param bool $deep Indicates whether to fetch deep items
     *
     * @return mixed|null The value of the parameter or null if not found
     */
    public function get($key, $default = null, $deep = false)
    {
        $data = (json_decode((string) \Tools::file_get_contents('php://input'), true) ?? []);

        if (parent::get($key)) {
            return parent::get($key);
        }

        if (is_array($data) && isset($data[$key])) {
            return $data[$key];
        }

        return $default;
    }
}
