<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

namespace JustIdea\ExpertSender\Infrastructure\Response;

use Symfony\Component\HttpFoundation\JsonResponse as BaseJsonResponse;

if (!defined('_PS_VERSION_')) {
    exit;
}

class JsonResponse extends BaseJsonResponse
{
    /**
     * Constructs a new JsonResponse object.
     *
     * @param mixed $data The response content
     * @param int $status The response status code (default: 200)
     * @param array<int|string, mixed> $headers An array of response headers (default: [])
     *
     * @throws \InvalidArgumentException When the HTTP status code is not valid
     */
    public function __construct($data = null, int $status = 200, array $headers = [])
    {
        parent::__construct($data, $status, $headers);
    }

    /**
     * Creates a new JsonResponse object representing a successful response.
     *
     * @param array<int|string, mixed> $data The response data
     * @param int $status The response status code (default: 200)
     *
     * @return self A new JsonResponse object
     */
    public static function success(array $data, int $status = 200): self
    {
        return new self([
            'success' => true,
            'errors' => [],
            'data' => $data,
        ], $status);
    }

    /**
     * Creates a new JsonResponse object representing an error response.
     *
     * @param string|array $error The error message or array of error messages
     * @param int $status The response status code (default: 400)
     *
     * @return self A new JsonResponse object
     */
    public static function error($error, int $status = 400): self
    {
        if (!is_array($error)) {
            $error = [$error];
        }

        if (JsonResponse::HTTP_UNPROCESSABLE_ENTITY === $status) {
            foreach ($error as $key => $messages) {
                $error[$key] = array_values($messages);
            }
        }

        return new self([
            'success' => false,
            'errors' => $error,
            'data' => [],
        ], $status);
    }
}
