<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Translator;

use JustIdea\ExpertSender\Core\Config\Config;

if (!defined('_PS_VERSION_')) {
    exit;
}

class AdminLegacyModuleTabTranslator implements AdminModuleTabTranslatorInterface
{
    /**
     * Translates the given key into the corresponding translation.
     *
     * If a translation for the provided key is found in the translations array,
     * it returns the translated value. Otherwise, it returns the key itself.
     *
     * @param string $key The key to translate
     *
     * @return string|array<string, string> Translated value if found, otherwise the key itself
     */
    public function translate(string $key)
    {
        return isset($this->getTranslations()[$key]) ? $this->getTranslations()[$key] : $key;
    }

    /**
     * Retrieves the array of translations.
     *
     * Returns an array where each key corresponds to a translation key,
     * and each value is an array of translations in different languages.
     *
     * @return array<string, array<string, string>> Array of translations
     */
    private function getTranslations(): array
    {
        return [
            Config::SIDEBAR_CONTROLLER => [
                'en' => 'ECDP',
                'en-US' => 'ECDP',
                'pl' => 'ECDP',
            ],
            Config::TAB_CONTROLLER => [
                'en' => 'Settings',
                'en-US' => 'Settings',
                'pl' => 'Ustawienia',
            ],
            Config::SETTINGS_CONTROLLER => [
                'en' => 'Settings',
                'en-US' => 'Settings',
                'pl' => 'Ustawienia',
            ],
            Config::ASSOCIATION_CONTROLLER => [
                'en' => 'Associations',
                'en-US' => 'Associations',
                'pl' => 'Powiązania',
            ],
            Config::LOG_CONTROLLER => [
                'en' => 'Logs',
                'en-US' => 'Logs',
                'pl' => 'Logi',
            ],
            Config::ASSOCIATION_CONSENTS_CONTROLLER => [
                'en' => 'Consents Associations',
                'en-US' => 'Consents Associations',
                'pl' => 'Powiązania Zgód',
            ],
            Config::ASSOCIATION_CUSTOMERS_CONTROLLER => [
                'en' => 'Customers Associations',
                'en-US' => 'Customers Associations',
                'pl' => 'Powiązania Klientów',
            ],
            Config::ASSOCIATION_ORDERS_CONTROLLER => [
                'en' => 'Orders Associations',
                'en-US' => 'Orders Associations',
                'pl' => 'Powiązania Zamówień',
            ],
            Config::ASSOCIATION_ORDER_STATES_CONTROLLER => [
                'en' => 'Order States Associations',
                'en-US' => 'Order States Associations',
                'pl' => 'Powiązania Statusów Zamówień',
            ],
            Config::ASSOCIATION_PRODUCTS_CONTROLLER => [
                'en' => 'Products Associations',
                'en-US' => 'Products Associations',
                'pl' => 'Powiązania Produktów',
            ],
            Config::IMPORT_ORDER_CONTROLLER => [
                'en' => 'Export Orders',
                'en-US' => 'Export Orders',
                'pl' => 'Eksportowanie Zamówień',
            ],
            Config::IMPORT_CUSTOMER_CONTROLLER => [
                'en' => 'Export Customers',
                'en-US' => 'Export Customers',
                'pl' => 'Eksportowanie Klientów',
            ],
            Config::SYNC_CONTROLLER => [
                'en' => 'Sync',
                'en-US' => 'Sync',
                'pl' => 'Synchronizacja',
            ],
            Config::LOGGER_AJAX_CONTROLLER => [
                'en' => 'Log ajax',
                'en-US' => 'Log ajax',
                'pl' => 'Ajax logów',
            ],
            Config::AJAX_CONTROLLER => [
                'en' => 'Ajax',
                'en-US' => 'Ajax',
                'pl' => 'Ajax',
            ],
            Config::CRON_CONTROLLER => [
                'en' => 'Cron',
                'en-US' => 'Cron',
                'pl' => 'Cron',
            ],
        ];
    }
}
