<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Utility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class ArrayUtility
{
    /**
     * Ensures that the input is an array.
     *
     * @param mixed $param Input parameter
     *
     * @return array The input array, or an empty array if the input is not an array
     */
    public static function getArray($param): array
    {
        return is_array($param) ? $param : [];
    }

    /**
     * Ensures that the input is a multidimensional array.
     *
     * @param mixed $param Input parameter
     *
     * @return array The input multidimensional array, or a single-element array containing the input if it's not already an array
     */
    public static function getMultidimensionalArray($param): array
    {
        if (empty($param)) {
            return [];
        }

        if (is_array(current($param))) {
            return $param;
        }

        return [$param];
    }

    /**
     * Indexes an array by a specified key.
     *
     * @param array $array The input array to be indexed
     * @param string $keyName The key to use for indexing
     *
     * @return array The indexed array
     */
    public static function indexBy(array $array, string $keyName): array
    {
        $indexedArray = [];

        foreach ($array as $index => $item) {
            $key = $item[$keyName] ?? null;

            if (null !== $key) {
                if (!isset($indexedArray[$key])) {
                    $indexedArray[$key] = [$index];
                } else {
                    $indexedArray[$key][] = $index;
                }
            }
        }

        return $indexedArray;
    }
}
