<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Utility;

use JustIdea\ExpertSender\Core\Enum\Gender;
use JustIdea\ExpertSender\Infrastructure\Adapter\Validate;

if (!defined('_PS_VERSION_')) {
    exit;
}

class CustomerInfoUtility
{
    public static function convertPhoneToValidFormat(string $phone): ?string
    {
        $phoneFormatted = $phone ? preg_replace('/[^0-9.]+/', '', $phone) : null;

        return $phone ? (Validate::isPhoneNumber($phoneFormatted) ? $phoneFormatted : null) : null;
    }

    public static function convertGenderIdToValidFormat(int $genderId): ?string
    {
        $gender = Gender::NOT_SPECIFIED;

        if ($genderId) {
            $genderObj = new \Gender($genderId);

            switch ($genderObj->type) {
                case Gender::ID_MALE:
                    $gender = Gender::MALE;
                    break;
                case Gender::ID_FEMALE:
                    $gender = Gender::FEMALE;
                    break;
                case Gender::ID_NOT_SPECIFIED:
                default:
                    $gender = Gender::NOT_SPECIFIED;
                    break;
            }
        }

        return $gender;
    }
}
