<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Utility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class DirUtility
{
    /**
     * Copies the override folder for the given module.
     *
     * @param \ExpertSenderOfficial $module The module to copy the override folder for
     *
     * @return bool Returns true on success, false otherwise
     */
    public static function copyOverrideFolder(\ExpertSenderOfficial $module): bool
    {
        if (!is_writable(_PS_MODULE_DIR_ . $module->name)) {
            return false;
        }

        $override_folder_name = 'override';

        if (VersionUtility::isPsVersionLessOrEqualTo('8.0.0')) {
            $version = '17';
        } else {
            $version = '8';
        }

        $version_override_folder = _PS_MODULE_DIR_ . $module->name . '/' . $override_folder_name . '_' . $version;
        $override_folder = _PS_MODULE_DIR_ . $module->name . '/' . $override_folder_name;

        if (file_exists($override_folder) && is_dir($override_folder)) {
            self::recursiveRmdir($override_folder);
        }

        if (is_dir($version_override_folder)) {
            self::copyDir($version_override_folder, $override_folder);
        }

        return true;
    }

    /**
     * Copies directory recursively from source to destination.
     *
     * @param string $src Source directory
     * @param string $dst Destination directory
     *
     * @return void
     */
    public static function copyDir(string $src, string $dst): void
    {
        if (is_dir($src)) {
            $dir = opendir($src);
            mkdir($dst);
            while (false !== ($file = readdir($dir))) {
                if (('.' != $file) && ('..' != $file)) {
                    if (is_dir($src . '/' . $file)) {
                        self::copyDir($src . '/' . $file, $dst . '/' . $file);
                    } else {
                        copy($src . '/' . $file, $dst . '/' . $file);
                    }
                }
            }
            closedir($dir);
        }
    }

    /**
     * Recursively removes a directory and its contents.
     *
     * @param string $dir Directory to remove
     *
     * @return void
     */
    public static function recursiveRmdir(string $dir): void
    {
        if (is_dir($dir)) {
            $objects = scandir($dir);
            foreach ($objects as $object) {
                if ('.' != $object && '..' != $object) {
                    if ('dir' == filetype($dir . '/' . $object)) {
                        self::recursiveRmdir($dir . '/' . $object);
                    } else {
                        unlink($dir . '/' . $object);
                    }
                }
            }
            reset($objects);
            rmdir($dir);
        }
    }
}
