<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Utility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class FieldsMappingUtility
{
    /**
     * serializeFieldsMapping returns an array with the mapping fields and field values as a json string
     *
     * @param int $idMappingField value
     * @param int $idMappingFieldValue value
     *
     * @return string json string
     */
    public static function serializeFieldsMapping(int $idMappingField, int $idMappingFieldValue): string
    {
        return (string) json_encode([
            'id_mapping_field' => $idMappingField,
            'id_mapping_field_value' => $idMappingFieldValue,
        ]);
    }

    /**
     * serializeConsentFieldsMapping returns an array with the mapping fields and field values, double optin and confirmation Id as a json string
     *
     * @param int $idMappingField value
     * @param int $idMappingFieldValue value
     * @param int $doubleOptin value
     * @param int $doubleOptinConfId value
     *
     * @return string json string
     */
    public static function serializeConsentFieldsMapping(int $idMappingField, int $idMappingFieldValue, int $doubleOptin, int $doubleOptinConfId): string
    {
        return (string) json_encode([
            'id_mapping_field' => $idMappingField,
            'id_mapping_field_value' => $idMappingFieldValue,
            'double_optin' => $doubleOptin,
            'double_optin_conf_id' => $doubleOptinConfId,
        ]);
    }

    /**
     * DeserializeFieldsMapping returns an associative array with the mapping fields and field values
     *
     * @param string $jsonString The JSON string to deserialize
     *
     * @return array<string, int> Associative array with keys 'id_mapping_field' and 'id_mapping_field_value', both being integers
     */
    public static function deserializeFieldsMapping(string $jsonString): array
    {
        $mappingsField = $jsonString && json_decode($jsonString, true) ? json_decode($jsonString, true) : [];

        if (!is_array($mappingsField)) {
            return [];
        }

        $mappingFieldId = isset($mappingsField['id_mapping_field']) ? (int) $mappingsField['id_mapping_field'] : 0;
        $mappingFieldValueId = isset($mappingsField['id_mapping_field_value']) ? (int) $mappingsField['id_mapping_field_value'] : 0;

        return [
            'id_mapping_field' => $mappingFieldId,
            'id_mapping_field_value' => $mappingFieldValueId,
        ];
    }

    /**
     * DeserializeConsentFieldsMapping returns an associative array with the mapping fields and field values
     *
     * @param string $jsonString The JSON string to deserialize
     *
     * @return array<string, int> Associative array with keys 'id_mapping_field', 'id_mapping_field_value', 'double_optin' and 'double_optin_conf_id', all being integers
     */
    public static function deserializeConsentFieldsMapping(string $jsonString): array
    {
        $mappingsField = $jsonString && json_decode($jsonString, true) ? json_decode($jsonString, true) : [];

        if (!is_array($mappingsField)) {
            return [];
        }

        $mappingFieldId = isset($mappingsField['id_mapping_field']) ? (int) $mappingsField['id_mapping_field'] : 0;
        $mappingFieldValueId = isset($mappingsField['id_mapping_field_value']) ? (int) $mappingsField['id_mapping_field_value'] : 0;
        $doubleOptin = isset($mappingsField['double_optin']) ? (int) $mappingsField['double_optin'] : 0;
        $doubleOptinConfId = isset($mappingsField['double_optin_conf_id']) ? (int) $mappingsField['double_optin_conf_id'] : 0;

        return [
            'id_mapping_field' => $mappingFieldId,
            'id_mapping_field_value' => $mappingFieldValueId,
            'double_optin' => $doubleOptin,
            'double_optin_conf_id' => $doubleOptinConfId,
        ];
    }
}
