<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

declare(strict_types=1);

namespace JustIdea\ExpertSender\Infrastructure\Utility;

if (!defined('_PS_VERSION_')) {
    exit;
}

class VersionUtility
{
    public static function isPsVersionGreaterThan(string $version): bool
    {
        return (bool) version_compare(_PS_VERSION_, $version, '>');
    }

    public static function isPsVersionGreaterOrEqualTo(string $version): bool
    {
        return (bool) version_compare(_PS_VERSION_, $version, '>=');
    }

    public static function isPsVersionLessThan(string $version): bool
    {
        return (bool) version_compare(_PS_VERSION_, $version, '<');
    }

    public static function isPsVersionLessOrEqualTo(string $version): bool
    {
        return (bool) version_compare(_PS_VERSION_, $version, '<=');
    }

    public static function isPsVersionEqualTo(string $version): bool
    {
        return (bool) version_compare(_PS_VERSION_, $version, '=');
    }

    public static function isPhpVersionGreaterThan(string $version): bool
    {
        $versionId = self::convertVersionToId($version);

        return (bool) PHP_VERSION_ID > $versionId;
    }

    public static function isPhpVersionGreaterOrEqualTo(string $version): bool
    {
        $versionId = self::convertVersionToId($version);

        return (bool) PHP_VERSION_ID >= $versionId;
    }

    public static function isPhpVersionLessThan(string $version): bool
    {
        $versionId = self::convertVersionToId($version);

        return (bool) PHP_VERSION_ID < $versionId;
    }

    public static function isPhpVersionLessOrEqualTo(string $version): bool
    {
        $versionId = self::convertVersionToId($version);

        return (bool) PHP_VERSION_ID <= $versionId;
    }

    public static function isPhpVersionEqualTo(string $version): bool
    {
        $versionId = self::convertVersionToId($version);

        return (bool) PHP_VERSION_ID === $versionId;
    }

    private static function convertVersionToId(string $version): bool
    {
        $parts = explode('.', $version);
        $major = isset($parts[0]) ? (int) $parts[0] : 0;
        $minor = isset($parts[1]) ? (int) $parts[1] : 0;
        $patch = isset($parts[2]) ? (int) $parts[2] : 0;

        return (bool) ($major * 10000 + $minor * 100 + $patch);
    }
}
