<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * This function updates module from previous versions to the version 1.0.1
 */
function upgrade_module_1_0_1($module)
{
    $db = Db::getInstance();

    $createTableSql1 = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'expertsender_customer_consent` (
                `id_customer_consent` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
                `id_customer` INT(11) UNSIGNED NOT NULL,
                `id_field` INT(11) UNSIGNED NOT NULL,
                `synced` TINYINT(1) NOT NULL DEFAULT 0,
                `date_add` DATETIME NOT NULL,
                `date_sync` DATETIME DEFAULT NULL,
            PRIMARY KEY (`id_customer_consent`),
            UNIQUE KEY `customer_consent` (`id_customer`, `id_field`),
            INDEX `idx_id_customer_consent` (`id_customer_consent`),
            INDEX `idx_id_customer` (`id_customer`),
            INDEX `idx_id_field` (`id_field`),
            INDEX `idx_synced` (`synced`),
            INDEX `idx_date_sync` (`date_sync`),
            FOREIGN KEY (`id_customer`) REFERENCES ' . _DB_PREFIX_ . 'customer (`id_customer`) ON DELETE CASCADE
        ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;';

    if (!$db->execute($createTableSql1)) {
        return false;
    }

    $alterIndexSql1 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_consent_mapping`
        ADD INDEX `idx_id_consent_mapping` (`id_consent_mapping`),
        ADD INDEX `idx_id_field` (`id_field`),
        ADD INDEX `idx_id_expertsender_field` (`id_expertsender_field`),
        ADD INDEX `idx_active` (`active`)';

    if (!$db->execute($alterIndexSql1)) {
        return false;
    }

    $alterIndexSql2 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_customer_mapping`
        ADD INDEX `idx_id_customer_mapping` (`id_customer_mapping`),
        ADD INDEX `idx_id_field` (`id_field`),
        ADD INDEX `idx_id_expertsender_field` (`id_expertsender_field`),
        ADD INDEX `idx_active` (`active`)';

    if (!$db->execute($alterIndexSql2)) {
        return false;
    }

    $alterIndexSql3 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_order_mapping`
        ADD INDEX `idx_id_order_mapping` (`id_order_mapping`),
        ADD INDEX `idx_id_field` (`id_field`),
        ADD INDEX `idx_id_expertsender_field` (`id_expertsender_field`),
        ADD INDEX `idx_active` (`active`)';

    if (!$db->execute($alterIndexSql3)) {
        return false;
    }

    $alterIndexSql4 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_product_mapping`
        ADD INDEX `idx_id_product_mapping` (`id_product_mapping`),
        ADD INDEX `idx_id_field` (`id_field`),
        ADD INDEX `idx_id_expertsender_field` (`id_expertsender_field`),
        ADD INDEX `idx_active` (`active`)';

    if (!$db->execute($alterIndexSql4)) {
        return false;
    }

    $alterIndexSql5 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_order_state_mapping`
        ADD INDEX `idx_id_order_state_mapping` (`id_order_state_mapping`),
        ADD INDEX `idx_id_field` (`id_field`),
        ADD INDEX `idx_id_expertsender_field` (`id_expertsender_field`),
        ADD INDEX `idx_active` (`active`)';

    if (!$db->execute($alterIndexSql5)) {
        return false;
    }

    $alterIndexSql6 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_order_state_mapping_relation`
        ADD INDEX `idx_id_order_state_mapping_relation` (`id_order_state_mapping_relation`),
        ADD INDEX `idx_id_order_state_mapping` (`id_order_state_mapping`),
        ADD INDEX `idx_id_order_state` (`id_order_state`)';

    if (!$db->execute($alterIndexSql6)) {
        return false;
    }

    $alterIndexSql7 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_log`
        ADD INDEX `idx_id_expertsender_log` (`id_expertsender_log`)';

    if (!$db->execute($alterIndexSql7)) {
        return false;
    }

    $alterIndexSql8 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_customer`
        ADD INDEX `idx_id_customer` (`id_customer`)';

    if (!$db->execute($alterIndexSql8)) {
        return false;
    }

    $alterIndexSql9 = 'ALTER TABLE `' . _DB_PREFIX_ . 'expertsender_order`
        ADD INDEX `idx_id_order` (`id_order`)';

    if (!$db->execute($alterIndexSql9)) {
        return false;
    }

    if (!$module->registerHook('actionObjectCustomerUpdateBefore')) {
        return false;
    }

    return true;
}
