<?php
/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

use JustIdea\ExpertSender\Core\Config\Config;
use JustIdea\ExpertSender\Infrastructure\Adapter\Tab;
use JustIdea\ExpertSender\Infrastructure\Translator\AdminLegacyModuleTabTranslator;

/**
 * This function updates module from previous versions to the version 1.0.3
 */
function upgrade_module_1_0_3($module)
{
    $controllerNames = [
        Config::SIDEBAR_CONTROLLER,
        Config::IMPORT_ORDER_CONTROLLER,
        Config::IMPORT_CUSTOMER_CONTROLLER,
    ];

    foreach ($controllerNames as $controllerName) {
        updateTabNameForController($controllerName);
    }

    return true;
}

/**
 * Updates the tab name for a given controller.
 *
 * @param string $controllerName
 *
 * @return void
 */
function updateTabNameForController(string $controllerName): void
{
    $tabAdapter = new Tab();
    $translator = new AdminLegacyModuleTabTranslator();

    $tabId = $tabAdapter->getIdFromClassName($controllerName);

    if ($tabId) {
        $tab = $tabAdapter->initTab($tabId);

        foreach (Language::getLanguages(false) as $language) {
            $translatedName = $translator->translate($controllerName);
            $tab->name[$language['id_lang']] = $translatedName[$language['iso_code']] ?? $translatedName['en'];
        }

        $tab->save();
    }
}
