/**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
function ExpertSenderOfficial() {
  this.ajaxUrl = expertsender.ajaxUrl;
  this.cronUrl = expertsender.cronUrl;
  this.ajaxToken = expertsender.ajaxToken;
  this.messages = expertsender.messages;
  this.enums = expertsender.enums;
  this.selectors = expertsender.selectors;
  this.ajaxRequest = [];
  this.isSyncActive = false;
}

ExpertSenderOfficial.prototype = {
  constructor: ExpertSenderOfficial,

  initializeSyncForm: function() {
    this.toggleSyncButtons();
    this.toggleSyncProgressBar();
  },

  startSyncJob: function() {
    self = this;
    if (this.isSyncActive || this.ajaxRequest.length > 0) {
        return;
    }
        
    this.isSyncActive = true;
    this.toggleSyncButtons();
    self.toggleSyncProgressBar();

    const syncOrders = $(`#${this.selectors.SYNC_FORM_ID}`).find(`input[name="${this.selectors.SYNC_ORDERS_SWITCH_NAME}"]:checked`).prop('value');
    const syncCustomers = $(`#${this.selectors.SYNC_FORM_ID}`).find(`input[name="${this.selectors.SYNC_CUSTOMERS_SWITCH_NAME}"]:checked`).prop('value');
    const syncReset = $(`#${this.selectors.SYNC_FORM_ID}`).find(`input[name="${this.selectors.SYNC_RESET_SWITCH_NAME}"]:checked`).prop('value');

    const data = {
      action: 'initSyncSubmit',
      orders: syncOrders,
      customers: syncCustomers,
      ecdp_sync_reset: syncReset,
    };
    this.ajaxPOST(data, null, function (response) {
      syncForm = $(`#${self.selectors.SYNC_FORM_ID}`);
      const logsContainerElement = syncForm.find(`#${self.selectors.SYNC_LOGGER_TEXTAREA}`);
      self.fillLogContainer(response['logs'], logsContainerElement);
  
      self.processSyncJob(syncOrders, syncCustomers);
    },
    null, 
    function() {
      self.toggleSyncButtons();
      self.toggleSyncProgressBar();
    });
  },

  stopSyncJob: function() {
    this.isSyncActive = false;
    this.toggleSyncButtons();
    self.toggleSyncProgressBar();
  },

  toggleSyncButtons: function() {
    $(`#${this.selectors.SYNC_BTN_START_ID}`).toggle(!this.isSyncActive);
    $(`#${this.selectors.SYNC_BTN_STOP_ID}`).toggle(this.isSyncActive);
    if (this.ajaxRequest.length) {
        $(`#${this.selectors.SYNC_BTN_START_ID}`).prop('disabled', true);
      } else {
        $(`#${this.selectors.SYNC_BTN_START_ID}`).prop('disabled', false)
      }
  },

  toggleSyncProgressBar: function() {
    if (this.ajaxRequest.length) {
      $(`#${this.selectors.SYNC_LOGS_PROGRESS_BAR_ID}`).toggle(true);
      } else {
        $(`#${this.selectors.SYNC_LOGS_PROGRESS_BAR_ID}`).toggle(this.isSyncActive);
      }
  },

  processSyncJob: function (syncOrders, syncCustomers) {
    var self = this;
    if (!self.isSyncActive) {
      self.toggleSyncButtons();
      self.toggleSyncProgressBar();
      return;
    };

    syncForm = $(`#${self.selectors.SYNC_FORM_ID}`);

    const data = {
        action: 'handleSyncSubmit',
        orders: syncOrders,
        customers: syncCustomers,
    };

    self.ajaxPOST(data, function () {
      syncForm.closest('.panel').css('pointer-events', 'none').fadeTo('fast', 0.2);

    }, function (response) {
      const logsContainerElement = syncForm.find(`#${self.selectors.SYNC_LOGGER_TEXTAREA}`);

      self.fillLogContainer(response['logs'], logsContainerElement);

      fillLastTimeSyncInfo(response, syncForm);

      if (!response.continue) {
        self.stopSyncJob();
      }

      self.processSyncJob(syncOrders, syncCustomers);

      function fillLastTimeSyncInfo(response, syncForm) {
        if (response['order_sync_runtime']) {
          syncForm.find('#expertsender-sync-order-timestamp').html(response['order_sync_runtime']).fadeOut(150).fadeIn(150).fadeOut(150).fadeIn(150);
        }
        if (response['order_sync_object_id']) {
          syncForm.find('#expertsender-sync-order-object-id').html(response['order_sync_object_id']).fadeOut(150).fadeIn(150).fadeOut(150).fadeIn(150);
        }
        if (response['customer_sync_runtime']) {
          syncForm.find('#expertsender-sync-customer-timestamp').html(response['customer_sync_runtime']).fadeOut(150).fadeIn(150).fadeOut(150).fadeIn(150);
        }
        if (response['customer_sync_object_id']) {
          syncForm.find('#expertsender-sync-customer-object-id').html(response['customer_sync_object_id']).fadeOut(150).fadeIn(150).fadeOut(150).fadeIn(150);
        }
      }
    },
    null, 
    function() {
      self.toggleSyncButtons();
      self.toggleSyncProgressBar();
    }
    );
  },
  

  fillLogContainer: function(newLogs, logsContainerElement) {
    const existingLogs = $(logsContainerElement).html().trim();
    $(logsContainerElement).html((existingLogs ? existingLogs + '\n' : existingLogs) + newLogs);

    const scrollHeight = $(logsContainerElement).prop('scrollHeight');
    $(logsContainerElement).animate({scrollTop:scrollHeight}, 300);
  },

  initializeDatePicker: function($selector) {
    $($selector).datetimepicker({
      beforeShow: function (input, inst) {
            setTimeout(function () {
                inst.dpDiv.css({
                    'z-index': 1031
                });
            }, 0);
        },
      prevText: '',
      nextText: '',
      dateFormat: 'yy-mm-dd',
      currentText: this.messages.DATE_PICKER_CURRENT_TEXT,
      closeText:this.messages.DATE_PICKER_CLOSE_TEXT,
      ampm: false,
      amNames: ['AM', 'A'],
      pmNames: ['PM', 'P'],
      timeFormat: 'hh:mm:ss tt',
      timeSuffix: '',
      timeOnlyTitle: this.messages.DATE_PICKER_TIME_ONLY_TITLE,
      timeText: this.messages.DATE_PICKER_TIME_TEXT,
      hourText: this.messages.DATE_PICKER_HOUR_TEXT,
      minuteText: this.messages.DATE_PICKER_MINUTE_TEXT,
    });
  },

  initializeMappingForm: function () {
    var self = this;
    var $fieldsetMappings = $('#fieldset_form_mapping');

    $fieldsetMappings.find('select.es-chosen.es-internal-mapping-field-value').each(function() {
      const currentSelect = $(this);
      const currentOptions = $.map(currentSelect.find('option'), function(option) {
          return {
              id: $(option).val(),
              name: $(option).text()
          };
      });
      const selectedId = currentSelect.val();

      self.fillSelect(currentOptions, this, selectedId);
    })

    $fieldsetMappings.find('select.es-chosen').chosen({
      width: '250px',
      no_results_text: self.messages.SEARCH_NO_RESULTS,
      include_group_label_in_selected:true
    });

    $fieldsetMappings.on('change', 'select.es-internal-mapping', function () {
      var typeId = $(this).prop('value');

      if (typeId == self.enums.SELECT_CHOOSE || typeId == self.enums.SELECT_ANY) {
        self.removeSelectOptions($('.es-internal-mapping-field'))
        self.hideSelectOptions($('.es-internal-mapping-field'))
        self.removeSelectOptions($('.es-internal-mapping-field-value'))
        self.hideSelectOptions($('.es-internal-mapping-field-value'))

        $fieldsetMappings.parent().find('select.es-internal-mapping').parent().closest('.panel').find('.mapping-input-error').remove();
        return;
      }

      self.changeInternalMapping(typeId, $(this).closest('.form-wrapper'), $(this).closest('select.es-internal-mapping').parent());
    });

    $fieldsetMappings.on('change', 'select.es-internal-mapping-field', function () {
      var typeId = $(this).closest('.form-wrapper').find('select.es-internal-mapping').prop('value');
      var fieldId = $(this).prop('value');

      if (fieldId == self.enums.SELECT_CHOOSE || fieldId == self.enums.SELECT_ANY) {
        self.removeSelectOptions($('.es-internal-mapping-field-value'))
        self.hideSelectOptions($('.es-internal-mapping-field-value'))

        $fieldsetMappings.parent().find('select.es-internal-mapping-field').parent().closest('.panel').find('.mapping-input-error').remove();
        return;
      }

      self.changeInternalMappingField(typeId, fieldId, $(this).closest('.form-wrapper'), $(this).closest('select.es-internal-mapping-field').parent());
    });

    $fieldsetMappings.on('change', 'select.es-internal-mapping-field-value', function () {
      var fieldValueId = $(this).prop('value');

      if (fieldValueId == self.enums.SELECT_CHOOSE || fieldValueId == self.enums.SELECT_ANY) {
        $('.es-internal-mapping-field-value').val(fieldValueId);

        $fieldsetMappings.parent().find('select.es-internal-mapping-field-value').parent().closest('.panel').find('.mapping-input-error').remove();
        return;
      }

      var selectElement = $(this).closest('select.es-internal-mapping-field-value')
      selectElement.trigger('chosen:updated');

    });

    $fieldsetMappings.on('change', 'select.es-api-mapping', function () {
      var mappingId = $(this).prop('value');

      if (mappingId == self.enums.SELECT_CHOOSE || mappingId == self.enums.SELECT_ANY) {
        $('.es-api-mapping-id').data('last-value', mappingId);
        $('.es-api-mapping-id').attr('last-value', mappingId);
        $('.es-api-mapping-hidden-id input[type="hidden"]').val(mappingId);
        $('.es-api-mapping-id').val(mappingId);

        $fieldsetMappings.parent().find('select.es-api-mapping').parent().closest('.panel').find('.mapping-input-error').remove();
        return;
      }

      self.changeApiMapping(mappingId, $(this).closest('select.es-api-mapping').parent());
    });

    $fieldsetMappings.on('focusout', 'input.es-api-mapping-id', function () {
      var mappingId = $(this).prop('value');

      if (mappingId == $('.es-api-mapping-hidden-id input[type="hidden"]').val() || mappingId == 0) {
        $fieldsetMappings.parent().find('select.es-api-mapping').parent().closest('.panel').find('.mapping-input-error').remove();
      }

      if (mappingId == $('.es-api-mapping-hidden-id input[type="hidden"]').val() || mappingId == $('.es-api-mapping-id').data('last-value') || mappingId == $('.es-api-mapping-id').attr('last-value') || mappingId == 0) {
        return;
      }

      self.changeApiMapping(mappingId, $fieldsetMappings.parent().find('select.es-api-mapping').parent());
    });
  },

  changeApiMapping: function (mappingId, selectBox) {
    var self = this;

    self.ajaxPOST({
      action: 'getMappings',
      id_mapping: mappingId
    }, function () {
      selectBox.closest('.panel').css('pointer-events', 'none').fadeTo('fast', 0.2);
      selectBox.closest('.panel').find('.mapping-input-error').remove();

    }, function (data) {
      var selectElement = selectBox.parent().find('select.es-api-mapping');

      if (data['mappings'].length) {
        fillSelect(data['mappings'], selectElement, mappingId);
        selectElement.chosen('destroy').chosen({
          width: '250px',
          no_results_text: self.messages.SEARCH_NO_RESULTS,
          include_group_label_in_selected:true
        });
        $('.es-api-mapping-hidden-name input').val(selectElement.find('option:selected').text());
      } else if (!data['mappings'].length) {
        selectElement.val(self.enums.SELECT_CHOOSE);
        selectElement.trigger('chosen:updated');

        $('.es-api-mapping-id').parent().append(`<p class='alert alert-danger mapping-input-error'>${self.messages.MAPPING_NOT_FOUND}</p>`);
      }

      selectBox.closest('.panel').css('pointer-events', 'auto').fadeTo('fast', 1);

      $('.es-api-mapping-id').data('last-value', mappingId);
      $('.es-api-mapping-id').attr('last-value', mappingId);
      $('.es-api-mapping-hidden-id input[type="hidden"]').val(mappingId);
      $('.es-api-mapping-id').val(mappingId);

      function fillSelect(newOptions, elementSelect, selectedId) {
        var isSelectedOptionFound = false;
        $('option', elementSelect).remove();

        $.each(newOptions, function (index, option) {
          var isSelected = selectedId == option['id'];
          if (isSelected) isSelectedOptionFound = true;
          var option = new Option(option['name'], option['id'], false, isSelected);
          elementSelect.append(option);
        });

        if (!isSelectedOptionFound) {
          elementSelect.val(self.enums.SELECT_CHOOSE);
        }

        elementSelect.trigger('chosen:updated');
      }
    });
  },

  changeInternalMapping: function (typeId, formFields) {
    var self = this;

    var fieldValueSelectElement = formFields.find('select.es-internal-mapping-field-value');
    var fieldSelectElement = formFields.find('select.es-internal-mapping-field');
    var internalMappingSelectElement = formFields.find('select.es-internal-mapping');
    var objectId = formFields.find('.es-form-object-hidden-id input[type="hidden"]').val();

    self.ajaxPOST({
      action: 'getMappingFields',
      id_type: typeId,
      id_form_object: objectId
    }, function () {
      fieldSelectElement.closest('.panel').css('pointer-events', 'none').fadeTo('fast', 0.2);
      fieldSelectElement.closest('.panel').find('.mapping-input-error').remove();

    }, function (data) {
      fieldSelectElement.closest('.form-group').removeClass('hidden');

      internalMappingSelectElement.trigger('chosen:updated');

      if (data['fields'].length) {
        fillSelect(data['fields'], fieldSelectElement, 0);
        fieldSelectElement.chosen('destroy').chosen({
          width: '250px',
          no_results_text: self.messages.SEARCH_NO_RESULTS,
          include_group_label_in_selected:true
        });
        self.showSelectOptions(fieldSelectElement);

      } else if (!data['fields'].length) {
        self.removeSelectOptions(fieldSelectElement);
        self.hideSelectOptions(fieldSelectElement);
      }

      self.removeSelectOptions(fieldValueSelectElement);
      self.hideSelectOptions(fieldValueSelectElement);

      fieldSelectElement.closest('.panel').css('pointer-events', 'auto').fadeTo('fast', 1);

      function fillSelect(newOptions, elementSelect, selectedId) {
        var isSelectedOptionFound = false;
        $('option', elementSelect).remove();

        $.each(newOptions, function (index, option) {
          var isSelected = selectedId == option['id'];
          if (isSelected) isSelectedOptionFound = true;
          var newOption = new Option(option['name'], option['id'], false, isSelected);
          
          if (option['disabled']) {
            $(newOption).prop('disabled', true);
          }
          elementSelect.append(newOption);
        });

        if (!isSelectedOptionFound) {
          elementSelect.val(self.enums.SELECT_CHOOSE);
        }

        elementSelect.trigger('chosen:updated');
      }
    });
  },

  changeInternalMappingField: function (typeId, fieldId, formFields) {
    var self = this;

    var fieldValueSelectElement = formFields.find('select.es-internal-mapping-field-value');
    var fieldSelectElement = formFields.find('select.es-internal-mapping-field');
    var internalMappingSelectElement = formFields.find('select.es-internal-mapping');

    self.ajaxPOST({
      action: 'getMappingFieldValues',
      id_type: typeId,
      id_field: fieldId
    }, function () {
      fieldValueSelectElement.closest('.panel').css('pointer-events', 'none').fadeTo('fast', 0.2);
      fieldValueSelectElement.closest('.panel').find('.mapping-input-error').remove();

    }, function (data) {
      fieldSelectElement.trigger('chosen:updated');
      fieldValueSelectElement.closest('.form-group').removeClass('hidden');

      if (data['fieldValues'].length) {
        fillSelect(data['fieldValues'], fieldValueSelectElement, 0);
        fieldValueSelectElement.chosen('destroy').chosen({
          width: '250px',
          no_results_text: self.messages.SEARCH_NO_RESULTS,
          include_group_label_in_selected:true
        });
        self.showSelectOptions(fieldValueSelectElement);

      } else if (!data['fieldValues'].length) {
        self.removeSelectOptions(fieldValueSelectElement);
        self.hideSelectOptions(fieldValueSelectElement);

        // $('.es-internal-mapping-field').parent().append(`<p class='alert alert-danger mapping-input-error'>${self.messages.MAPPING_NOT_FOUND}</p>`);
      }

      fieldValueSelectElement.closest('.panel').css('pointer-events', 'auto').fadeTo('fast', 1);

      // $('.es-internal-mapping-field').val(fieldValueId);

      function fillSelect(newOptions, elementSelect, selectedId) {
        $(elementSelect).empty();
    
        const optionGroupOthers = $('<optgroup>', { label: self.messages.SELECT_VALUES_GROUP_NAME });
    
        $.each(newOptions, function (index, option) {
            const isSelected = selectedId == option['id'];
            const newOption = $('<option>', {
                value: option['id'],
                text: option['name'],
                selected: isSelected
            });
    
            if (option['id'] == self.enums.SELECT_CHOOSE) {
                newOption.appendTo(elementSelect);
            } else if (option['id'] == self.enums.SELECT_ANY) {
                newOption.appendTo(elementSelect);
            } else {
                newOption.appendTo(optionGroupOthers);
            }
        });
    
        if (optionGroupOthers.children().length) optionGroupOthers.appendTo(elementSelect);

        $(elementSelect).trigger('chosen:updated');
      }
    });
  },

   fillSelect: function(newOptions, elementSelect, selectedId) {
    var self = this;

    $(elementSelect).empty();

    const optionGroupOthers = $('<optgroup>', { label: self.messages.SELECT_VALUES_GROUP_NAME });

    $.each(newOptions, function (index, option) {
        const isSelected = selectedId == option['id'];
        const newOption = $('<option>', {
            value: option['id'],
            text: option['name'],
            selected: isSelected
        });

        if (option['id'] == self.enums.SELECT_CHOOSE) {
            newOption.appendTo(elementSelect);
        } else if (option['id'] == self.enums.SELECT_ANY) {
            newOption.appendTo(elementSelect);
        } else {
            newOption.appendTo(optionGroupOthers);
        }
    });

    if (optionGroupOthers.children().length) optionGroupOthers.appendTo(elementSelect);

    $(elementSelect).trigger('chosen:updated');
  },

  ajaxPOST: function (data, beforeSend, success, error, always) {
    var self = this;
    var defaultData = {
      'token': self.ajaxToken,
      'ajax': true
    };

    var request = $.ajax({
      url: self.ajaxUrl,
      method: 'POST',
      async: true,
      dataType: 'json',
      data: $.extend(defaultData, data),
      beforeSend: beforeSend,
      success: function (json) {
        if (json && json.apiError) {
          $.each(json.messages, function (index, message) {
            showErrorMessage(message);
          });
        } else if (success) {
          success(json);
        }
      },
      error: error,
    }).always(function() {
        const index = self.ajaxRequest.indexOf(request);
        if (index > -1) {
            self.ajaxRequest.splice(index, 1);
        }
        if (always) {
          always();
        }
      });

    self.ajaxRequest.push(request);
  },

  ajaxAbort: function () {
    this.ajaxForceTerminateLoop = true;

    $.each(this.ajaxRequest, function (i, ajax) {
      ajax.abort();
    });

    this.ajaxRequest = [];
  },

  removeSelectOptions: function (elementSelect) {
    $('option', elementSelect).remove();

    elementSelect.trigger('chosen:updated');
  },

  showSelectOptions: function (elementSelect) {
    elementSelect.closest('.form-group').show();
  },

  hideSelectOptions: function (elementSelect) {
    elementSelect.closest('.form-group').hide();
  },
}

function redirectAfterConfirmation(url, message) {
  if (confirm(message)) {
      window.location.href = url;
  }
}