{**
 * Copyright since 2016 JustIdea Agency.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please contact us for extra customization service at an affordable price
 *
 * @author    JustIdea Agency <contact@justidea.agency>
 * @copyright 2016-2024 JustIdea Agency
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 *}

{extends file="helpers/options/options.tpl"}

{block name="input"}
    {if $field['type'] == 'select'}
        <div class="col-lg-9">
            {if $field['list']}
                <select class="form-control fixed-width-xxl {if isset($field['class'])}{$field['class']}{/if}" name="{$key}"{if isset($field['js'])} onchange="{$field['js']}"{/if} id="{$key}" {if isset($field['size'])} size="{$field['size']}"{/if}>
                    {foreach $field['list'] AS $k => $option}
                        <option value="{$option[$field['identifier']]}"{if $field['value'] == $option[$field['identifier']]} selected="selected"{/if}>{$option['name']}</option>
                    {/foreach}
                </select>
            {elseif isset($input.empty_message)}
                {$input.empty_message}
            {/if}
        </div>
    {elseif $field['type'] == 'bool'}
        <div class="col-lg-9">
            <span class="switch prestashop-switch fixed-width-lg">
                {strip}
                <input type="radio" name="{$key}" id="{$key}_on" value="1" {if $field['value']} checked="checked"{/if}{if isset($field['js']['on'])} {$field['js']['on']}{/if}{if isset($field['disabled']) && (bool)$field['disabled']} disabled="disabled"{/if}/>
                <label for="{$key}_on" class="radioCheck">
                    {l s='Yes' d='Admin.Global'}
                </label>
                <input type="radio" name="{$key}" id="{$key}_off" value="0" {if !$field['value']} checked="checked"{/if}{if isset($field['js']['off'])} {$field['js']['off']}{/if}{if isset($field['disabled']) && (bool)$field['disabled']} disabled="disabled"{/if}/>
                <label for="{$key}_off" class="radioCheck">
                    {l s='No' d='Admin.Global'}
                </label>
                {/strip}
                <a class="slide-button btn"></a>
            </span>
        </div>
    {elseif $field['type'] == 'radio'}
        <div class="col-lg-9">
            {foreach $field['choices'] AS $k => $v}
                <p class="radio">
                    {strip}
                    <label for="{$key}_{$k}">
                        <input type="radio" name="{$key}" id="{$key}_{$k}" value="{$k}"{if $k == $field['value']} checked="checked"{/if}{if isset($field['js'][$k])} {$field['js'][$k]}{/if}/>
                         {$v}
                    </label>
                    {/strip}
                </p>
            {/foreach}
        </div>
    {elseif $field['type'] == 'checkbox'}
        <div class="col-lg-9">
            {foreach $field['choices'] AS $k => $v}
                <p class="checkbox">
                    {strip}
                    <label class="col-lg-3" for="{$key}{$k}_on">
                        <input type="checkbox" name="{$key}" id="{$key}{$k}_on" value="{$k|intval}"{if $k == $field['value']} checked="checked"{/if}{if isset($field['js'][$k])} {$field['js'][$k]}{/if}/>
                         {$v}
                    </label>
                    {/strip}
                </p>
            {/foreach}
        </div>
    {elseif $field['type'] == 'text'}
        <div class="col-lg-9">{if isset($field['suffix'])}<div class="input-group{if isset($field.class)} {$field.class}{/if}">{/if}
            <input class="form-control {if isset($field['class'])}{$field['class']}{/if}" type="{$field['type']}"{if isset($field['id'])} id="{$field['id']}"{/if} size="{if isset($field['size'])}{$field['size']|intval}{else}5{/if}" name="{$key}" value="{if isset($field['no_escape']) && $field['no_escape']}{$field['value']}{else}{$field['value']|escape:'html':'UTF-8'}{/if}" {if isset($field['autocomplete']) && !$field['autocomplete']}autocomplete="off"{/if}/>
            {if isset($field['suffix'])}
            <span class="input-group-addon">
                {$field['suffix']}
            </span>
            {/if}
            {if isset($field['suffix'])}</div>{/if}
        </div>
    {elseif $field['type'] == 'password'}
        <div class="col-lg-9">{if isset($field['suffix']) || isset($field['prefix'])}<div class="input-group{if isset($field.class)} {$field.class}{/if}">{/if}
            {if isset($field['prefix'])}
                <span class="input-group-addon">
                    {$field['prefix']}
                </span>
            {/if}
            <input type="{$field['type']}"{if isset($field['id'])} id="{$field['id']}"{/if} size="{if isset($field['size'])}{$field['size']|intval}{else}5{/if}" name="{$key}" value="{if isset($field.value)}{$field.value}{/if}"{if isset($field['autocomplete']) && !$field['autocomplete']} autocomplete="off"{/if} />
            {if isset($field['suffix'])}
            <span class="input-group-addon">
                {$field['suffix']}
            </span>
            {/if}
            {if isset($field['suffix']) || isset($field['prefix'])}</div>{/if}
        </div>
    {elseif $field['type'] == 'textarea'}
        <div class="col-lg-9">
            <textarea class="{if isset($field['autoload_rte']) && $field['autoload_rte']}rte autoload_rte{else}textarea-autosize{/if}" name={$key}{if isset({$field['cols']})} cols="{$field['cols']}"{/if}{if isset({$field['rows']})} rows="{$field['rows']}"{/if}">{$field['value']|escape:'html':'UTF-8'}</textarea>
        </div>
    {elseif $field['type'] == 'file'}
        <div class="col-lg-9">{$field['file']}</div>
    {elseif $field['type'] == 'color'}
        <div class="col-lg-2">
            <div class="input-group">
                <input type="color" size="{$field['size']}" data-hex="true" {if isset($input.class)}class="{$field['class']}" {else}class="color mColorPickerInput"{/if} name="{$field['name']}" class="{if isset($field['class'])}{$field['class']}{/if}" value="{$field['value']|escape:'html':'UTF-8'}" />
            </div>
        </div>
    {elseif $field['type'] == 'price'}
        <div class="col-lg-9">
            <div class="input-group fixed-width-lg">
                <span class="input-group-addon">{$currency_left_sign} {l s='(tax excl.)' mod='expertsenderofficial'}</span>
                <input type="text" size="{if isset($field['size'])}{$field['size']|intval}{else}5{/if}" name="{$key}" value="{$field['value']|escape:'html':'UTF-8'}" />
            </div>
        </div>
    {elseif $field['type'] == 'textLang' || $field['type'] == 'textareaLang' || $field['type'] == 'selectLang'}
        {if $field['type'] == 'textLang'}
            <div class="col-lg-9">
                <div class="row">
                {foreach $field['languages'] AS $id_lang => $value}
                    {if $field['languages']|count > 1}
                    <div class="translatable-field lang-{$id_lang}" {if $id_lang != $current_id_lang}style="display:none;"{/if}>
                        <div class="col-lg-9">
                    {else}
                    <div class="col-lg-12">
                    {/if}
                            <input type="text"
                                name="{$key}_{$id_lang}"
                                value="{$value|escape:'html':'UTF-8'}"
                                {if isset($input.class)}class="{$input.class}"{/if}
                            />
                    {if $field['languages']|count > 1}
                        </div>
                        <div class="col-lg-2">
                            <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
                                {foreach $languages as $language}
                                    {if $language.id_lang == $id_lang}{$language.iso_code}{/if}
                                {/foreach}
                                <span class="caret"></span>
                            </button>
                            <ul class="dropdown-menu">
                                {foreach $languages as $language}
                                <li>
                                    <a href="javascript:hideOtherLanguage({$language.id_lang});">{$language.name}</a>
                                </li>
                                {/foreach}
                            </ul>
                        </div>
                    </div>
                    {else}
                    </div>
                    {/if}
                {/foreach}
                </div>
            </div>
        {elseif $field['type'] == 'textareaLang'}
            <div class="col-lg-9">
                {foreach $field['languages'] AS $id_lang => $value}
                    <div class="row translatable-field lang-{$id_lang}" {if $id_lang != $current_id_lang}style="display:none;"{/if}>
                        <div id="{$key}_{$id_lang}" class="col-lg-9" >
                            <textarea class="{if isset($field['autoload_rte']) && $field['autoload_rte']}rte autoload_rte{else}textarea-autosize{/if}" name="{$key}_{$id_lang}">{$value}</textarea>
                        </div>
                        <div class="col-lg-2">
                            <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
                                {foreach $languages as $language}
                                    {if $language.id_lang == $id_lang}{$language.iso_code}{/if}
                                {/foreach}
                                <span class="caret"></span>
                            </button>
                            <ul class="dropdown-menu">
                                {foreach $languages as $language}
                                <li>
                                    <a href="javascript:hideOtherLanguage({$language.id_lang});">{$language.name}</a>
                                </li>
                                {/foreach}
                            </ul>
                        </div>

                    </div>
                {/foreach}
                <script type="text/javascript">
                    $(document).ready(function() {
                        $(".textarea-autosize").autosize();
                    });
                </script>
            </div>
        {elseif $field['type'] == 'selectLang'}
            {foreach $languages as $language}
                <div id="{$key}_{$language.id_lang}" style="display: {if $language.id_lang == $current_id_lang}block{else}none{/if};" class="col-lg-9">
                    <select name="{$key}_{$language.iso_code}">
                        {foreach $field['list'] AS $k => $v}
                            <option value="{if isset($v.cast)}{$v.cast[$v[$field.identifier]]}{else}{$v[$field.identifier]}{/if}"
                                {if $field['value'][$language.id_lang] == $v['name']} selected="selected"{/if}>
                                {$v['name']}
                            </option>
                        {/foreach}
                    </select>
                </div>
            {/foreach}
        {/if}
    {/if}
    {if isset($field['desc']) && !empty($field['desc'])}
    <div class="col-lg-9 col-lg-offset-3">
        <div class="help-block">
            {if is_array($field['desc'])}
                {foreach $field['desc'] as $p}
                    {if is_array($p)}
                        <span id="{$p.id}">{$p.text}</span><br />
                    {else}
                        {$p}<br />
                    {/if}
                {/foreach}
            {else}
                {$field['desc']}
            {/if}
        </div>
    </div>
    {/if}
    
    {if $field['type'] == 'desc'}
        <div class="col-xs-12 {if isset($field['class'])}{$field['class']|escape:'htmlall':'UTF-8'}{/if}">
            {if $field['template'] == ExpertSenderConfig::API_TOKEN|cat:"_description"}
                {include file="../../../alerts/alert-info-field-token-desc.tpl"}
            {/if}
			{if $field['template'] == ExpertSenderConfig::IMPORT_CUSTOMER_DATE_FROM|cat:"_description" || $field['template'] == ExpertSenderConfig::IMPORT_ORDER_DATE_FROM|cat:"_description"}
				{include file="../../../alerts/alert-info-field-import-general-info"}
			{/if}
			{if $field['template'] == ExpertSenderConfig::IMPORT_CUSTOMER_NEWSLETTER_CONSENT|cat:"_description" || $field['template'] == ExpertSenderConfig::IMPORT_CUSTOMER_OPTIN_CONSENT|cat:"_description"}
				{include file="../../../alerts/alert-info-field-import-customers-consent.tpl"}
			{/if}
            {if $field['template'] == ExpertSenderConfig::WEBSITE_ID|cat:"_description"}
                {include file="../../../alerts/alert-info-field-website-id-desc.tpl"}
            {/if}
            {if $field['template'] == ExpertSenderConfig::SYNC_ORDERS|cat:"_description"}
                {include file="../../../alerts/alert-info-sync.tpl"}
            {/if}
			{if $field['template'] == ExpertSenderConfig::SYNC_INCLUDE_PHONE|cat:"_description"}
				{include file="../../../alerts/alert-info-include-phone.tpl"}
			{/if}
            {if $field['template'] == ExpertSenderConfig::OPTIONS_SYNC_SUBMIT|cat:"_description"}
                {include file="../../../alerts/alert-info-sync.tpl"}
            {/if}
            {if $field['template'] == ExpertSenderConfig::OPTIONS_SYNC_SUBMIT|cat:"_cron_description"}
                {include file="../../../alerts/alert-info-sync-cron.tpl"}
            {/if}
            {if $field['template'] == ExpertSenderConfig::OPTIONS_SYNC_SUBMIT|cat:"_details_description"}
                {include file="../../../alerts/alert-info-sync-details.tpl"}
            {/if}
        </div>
    {/if}

    {if $field['type'] == 'select-template'}
        <div class="field-container">
            {foreach from=$field['templateOptions'] key=key item=templateUrl}
                {assign var='key' value=$key + 1}
                <label class="field-label">
                    <input type="radio" name="{$field['name']|escape:'htmlall':'UTF-8'}" value="{$key|escape:'htmlall':'UTF-8'}"
                        {if $key == $field['value']}checked{/if}>
                    <img src="{$templateUrl|escape:'htmlall':'UTF-8'}">
                </label>
            {/foreach}
        </div>
    {/if}
{/block}